@@ -1,10 +1,11 @@
+from __future__ import annotations
+
 import dash
 from dash import html
 
 # standard Dash imports for callbacks (interactivity)
 from dash.dependencies import Input, Output
-from pymatgen.core.lattice import Lattice
-from pymatgen.core.structure import Structure
+from pymatgen.core import Lattice, Structure
 
 import crystal_toolkit.components as ctc
 
@@ -18,7 +19,9 @@ structures = [
 ]
 
 # we show the first structure by default
-structure_component = ctc.StructureMoleculeComponent(structures[0], id="my_structure")
+structure_component = ctc.StructureMoleculeComponent(
+    structures[0], id="hello_structure"
+)
 
 # and we create a button for user interaction
 my_button = html.Button("Swap Structure", id="change_structure_button")
@@ -33,11 +36,12 @@ ctc.register_crystal_toolkit(app=app, layout=my_layout)
 # for the interactivity, we use a standard Dash callback
 @app.callback(
     Output(structure_component.id(), "data"),
-    [Input("change_structure_button", "n_clicks")],
+    Input("change_structure_button", "n_clicks"),
 )
 def update_structure(n_clicks):
+    """Toggle between hexagonal and cubic structures on button click."""
     return structures[n_clicks % 2]
 
 
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
