@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import dash
 from dash import html
 
@@ -11,6 +13,6 @@ app.layout = html.Span(["Hello scientist!"])
 
 # run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
-# see Dash documentation for more information
+# see Dash docs for more info
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
