@@ -1,9 +1,8 @@
+from __future__ import annotations
+
 import dash
 from dash.dependencies import Input, Output
-
-# create our crystal structure using pymatgen
-from pymatgen.core.lattice import Lattice
-from pymatgen.core.structure import Structure
+from pymatgen.core import Lattice, Structure
 
 import crystal_toolkit.components as ctc
 from crystal_toolkit.helpers.layouts import H1, Button, Container
@@ -22,14 +21,14 @@ my_layout = Container([page_title, xrd_component.layout(), load_btn])
 ctc.register_crystal_toolkit(app=app, layout=my_layout)
 
 
-@app.callback(Output(xrd_component.id(), "data"), Input(load_btn.id, "n_clicks"))
+@app.callback(Output(xrd_component.id(), "data"), Input(load_btn, "n_clicks"))
 def load_structure(n_clicks: int) -> Structure:
-    structure = Structure(Lattice.cubic(4.2), ["Na", "K"], [[0, 0, 0], [0.5, 0.5, 0.5]])
-    return structure
+    """Load a cubic structure on button click."""
+    return Structure(Lattice.cubic(4.2), ["Na", "K"], [[0, 0, 0], [0.5, 0.5, 0.5]])
 
 
 # run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
-# see Dash documentation for more information
+# see Dash docs for more info
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
