@@ -1,12 +1,11 @@
+from __future__ import annotations
+
 import dash
 
 import crystal_toolkit.components as ctc
 from crystal_toolkit.helpers.layouts import H1, Container
 from crystal_toolkit.settings import SETTINGS
 
-# create our crystal structure using pymatgen
-
-
 app = dash.Dash(assets_folder=SETTINGS.ASSETS_PATH)
 
 xrd_component = ctc.XRayDiffractionComponent()
@@ -21,6 +20,6 @@ ctc.register_crystal_toolkit(app=app, layout=my_layout)
 
 # run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
-# see Dash documentation for more information
+# see Dash docs for more info
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
