@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import random
 
 import dash
@@ -60,6 +62,7 @@ my_layout = ctl.Section(
     Output("output", "children"), Input(your_component.get_all_kwargs_id(), "value")
 )
 def show_outputs(*args):
+    """Reconstruct the kwargs from the state of the component and display them as string."""
     kwargs = your_component.reconstruct_kwargs_from_state()
 
     return str(kwargs)
@@ -69,25 +72,24 @@ def show_outputs(*args):
     Output("dynamic-inputs", "children"), Input("generate-inputs", "n_clicks")
 )
 def add_inputs(n_clicks):
+    """Add a slider input with random initial value to the layout."""
     if not n_clicks:
         raise PreventUpdate
 
     element = random.choice(["Li", "Na", "K"])
-    slider_input = your_component.get_slider_input(
+    return your_component.get_slider_input(
         kwarg_label=f"slider_{element}",
         default=random.uniform(0, 1),
         label=f"{element} Slider Input",
         help_str="This can explain to the user what this slider input controls.",
     )
 
-    return slider_input
-
 
 # tell Crystal Toolkit about the app and layout we want to display
 ctc.register_crystal_toolkit(app=app, layout=my_layout, cache=None)
 
 # run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
-# see Dash documentation for more information
+# see Dash docs for more info
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
