@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 import logging
 import re
-from typing import List
 from urllib.parse import urljoin
 
 import dash
@@ -43,11 +44,15 @@ _ADSORBATE_CHOICES = (
 
 class CatalysisApp(MPApp):
     @staticmethod
-    def modify_df(dataframe: pd.DataFrame) -> List[pd.DataFrame]:
-        """
-        Filter DataFrame for binary visualization.
-        :param dataframe:
-        :return:
+    def modify_df(dataframe: pd.DataFrame) -> list[pd.DataFrame]:
+        """Filter DataFrame for unary+binary materials visualization.
+
+        Args:
+          dataframe (pd.DataFrame): the dataframe that you want to modify
+
+        Returns:
+            list[pd.Dataframe): two dataframes, the input df filtered to unary or binary materials
+                and one with the minimum energy of each material
         """
 
         # Extract the elements and number of them from formula
@@ -78,8 +83,8 @@ class CatalysisApp(MPApp):
         range_E,
         user_options,
     ) -> go.Figure:
-        """
-        Generate a 2D plot for binary visualization.
+        """Generate a 2D plot for binary visualization.
+
         :param df_all_data:
         :param df_min_E:
         :param target_E:
@@ -87,7 +92,6 @@ class CatalysisApp(MPApp):
         :param user_options: Not implemented.
         :return: 2D plot
         """
-
         # Create a list of unique elements for use as axis labels
         element_list = df_min_E.element_tup.tolist()
         flat_element_list = [item for sublist in element_list for item in sublist]
@@ -99,19 +103,16 @@ class CatalysisApp(MPApp):
             custom_data = np.zeros((grid_dim, grid_dim), dtype=object)
             add_data = np.zeros((grid_dim, grid_dim), dtype=object)
             lookup_dict = df_min_E.set_index("element_tup").to_dict()
-            el_combos = list(lookup_dict["energy"].keys())
-            for i in range(len(labels)):
-                for k in range(len(labels)):
-                    if i == k:
-                        els_now = tuple(
-                            [
-                                labels[i],
-                            ]
-                        )
-                    else:
-                        els_now = tuple(np.sort([labels[i], labels[k]]))
+            el_combos = list(lookup_dict["energy"])
+            for ii in range(len(labels)):
+                for kk in range(len(labels)):
+                    els_now = (
+                        (labels[ii],)
+                        if ii == kk
+                        else tuple(np.sort([labels[ii], labels[kk]]))
+                    )
                     if els_now in el_combos:
-                        grid[i, k] = lookup_dict["energy"][els_now]
+                        grid[ii, kk] = lookup_dict["energy"][els_now]
                         random_ids = df_all_data[
                             df_all_data["element_tup"] == els_now
                         ].identifier.tolist()
@@ -120,12 +121,12 @@ class CatalysisApp(MPApp):
                         for id in random_ids:
                             random_id_text = random_id_text + id + " <br> "
                             add_data_text = add_data_text + id + "-"
-                        custom_data[i, k] = [len(random_ids), random_id_text]
-                        add_data[i, k] = add_data_text
+                        custom_data[ii, kk] = [len(random_ids), random_id_text]
+                        add_data[ii, kk] = add_data_text
                     else:
-                        grid[i, k] = np.nan
-                        custom_data[i, k] = ["None", "None"]
-                        add_data[i, k] = "None"
+                        grid[ii, kk] = np.nan
+                        custom_data[ii, kk] = ["None", "None"]
+                        add_data[ii, kk] = "None"
             return grid, custom_data, add_data
 
         grid, customdata, add_data = construct_grid(df_min_E, labels)
@@ -136,7 +137,8 @@ class CatalysisApp(MPApp):
                 z=grid,
                 customdata=customdata,
                 text=add_data,
-                hovertemplate="<b>number of calculations</b>: %{customdata[0]} <br><br><b> Open Catalyst Project IDs: </b> %{customdata[1]} <extra></extra>",
+                hovertemplate="<b>number of calculations</b>: %{customdata[0]} <br><br><b> Open Catalyst Project IDs: "
+                "</b> %{customdata[1]} <extra></extra>",
                 colorscale=plotly.colors.cyclical.Twilight,
                 zmin=float(target_E[0]) - float(range_E[0]),
                 zmax=float(target_E[0]) + float(range_E[0]),
@@ -149,13 +151,15 @@ class CatalysisApp(MPApp):
 
         return fig
 
-    def get_catalysis_explorer(self):
+    def get_catalysis_explorer(self) -> mpc.SearchUIContainer:
+        """Get the Catalysis Explorer app."""
         return mpc.SearchUIContainer(
             [
                 self.search_bar_container(
                     mpc.SearchUISearchBar(
                         placeholder="e.g. Al3Pt5 or mp-10025",
-                        errorMessage='Please enter a valid bulk formula (e.g. "Ti5Ge4") or Material ID (e.g. "mp-1501").',
+                        errorMessage='Please enter a valid bulk formula (e.g. "Ti5Ge4") or Material ID '
+                        '(e.g. "mp-1501").',
                         periodicTableMode="none",
                         allowedInputTypesMap={
                             "formula": {"field": "data__bulkFormula__exact"},
@@ -193,7 +197,8 @@ class CatalysisApp(MPApp):
             fieldsKey="_fields",
         )
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
+        """Register callback functions for this component."""
         super().generate_callbacks(app, cache)
 
         @cache.memoize(timeout=60 * 60)
@@ -215,21 +220,17 @@ class CatalysisApp(MPApp):
                 }
                 for resp in contributions["data"]
             ]
-            df = pd.DataFrame(records)
-            return df
+            return pd.DataFrame(records)
 
         @app.callback(
             Output(self.id("heat_map"), "figure"),
-            [
-                Input(self.get_kwarg_id("smiles"), "value"),
-                Input(self.get_kwarg_id("targetE"), "value"),
-                Input(self.get_kwarg_id("range_E"), "value"),
-                Input(self.id("tabs"), "value"),
-            ],
+            Input(self.get_kwarg_id("smiles"), "value"),
+            Input(self.get_kwarg_id("targetE"), "value"),
+            Input(self.get_kwarg_id("range_E"), "value"),
+            Input(self.id("tabs"), "value"),
         )
         @cache.memoize(timeout=60 * 60 * 24)
         def update_figure(smile, mid_E, range_E, active_tab):
-
             # guard statement to ensure callback is not triggered unless viewing visualization
             if active_tab != "visualization":
                 raise PreventUpdate
@@ -237,8 +238,7 @@ class CatalysisApp(MPApp):
             smile = smile[0]
             df = get_plot_data(smile)
             df_full, df_min_E = self.modify_df(df)
-            plot = self.get_plot(df_full, df_min_E, mid_E, range_E, 1)
-            return plot
+            return self.get_plot(df_full, df_min_E, mid_E, range_E, 1)
 
         @app.callback(
             Output(self.id("display_table"), "children"),
@@ -256,10 +256,7 @@ class CatalysisApp(MPApp):
             else:
                 el1 = str(clickData["points"][0]["x"])
                 el2 = str(clickData["points"][0]["y"])
-                if el1 == el2:
-                    el_combo = el1
-                else:
-                    el_combo = el1 + ", " + el2
+                el_combo = el1 if el1 == el2 else el1 + ", " + el2
                 randids = clickData["points"][0]["text"].split("-")
                 num_calcs = str(len(randids) - 1)
                 table = ctl.get_data_list(
@@ -301,8 +298,7 @@ class CatalysisApp(MPApp):
         ).layout()
 
     def get_layout(self, payload=None):
-
-        tabs = dcc.Tabs(
+        return dcc.Tabs(
             [
                 dcc.Tab(
                     children=[html.Br(), self.get_search_layout(payload=payload)],
@@ -324,8 +320,6 @@ class CatalysisApp(MPApp):
             id=self.id("tabs"),
         )
 
-        return tabs
-
     def get_visualization_layout(self, payload=None):
         state = {"smiles": "*C", "targetE": 0.2, "range_E": 1}
         smiles_input = self.get_choice_input(
@@ -368,7 +362,7 @@ class CatalysisApp(MPApp):
             [description, html.Br(), html.Br(), smiles_input, E_input, range_input]
         )
 
-        viz_div = html.Div(
+        return html.Div(
             ctl.Columns(
                 [
                     ctl.Column(
@@ -409,24 +403,17 @@ class CatalysisApp(MPApp):
             )
         )
 
-        return viz_div
-
     def get_search_layout(self, payload=None):
-
         if not payload:
             return self.get_catalysis_explorer()
 
         client = get_contribs_client()
 
         # Fetch contribution-level data
-        # TODO use client._get_per_page_default_max?
-
-        contributions_resp = client.contributions.get_entries(
-            identifier=payload,
-            project="open_catalyst_project",
-            _fields=["id", "identifier", "project", "formula", "data", "structures"],
-            per_page=1,
-        ).result()
+        contributions_resp = client.query_contributions(
+            query={"project": "open_catalyst_project", "identifier": payload},
+            fields=["id", "identifier", "project", "formula", "data", "structures"],
+        )
 
         if not contributions_resp["data"]:
             logger.error(f"Failed to load contribution for {payload}")
@@ -439,7 +426,10 @@ class CatalysisApp(MPApp):
             structure = client.get_structure(contribution["structures"][0]["id"])
         except Exception as ex:
             logger.error(ex)
-            raise PreventUpdate
+            raise PreventUpdate from ex
+
+        bulk_formula = contribution["data"]["bulkFormula"]
+        adsorbate_smiles = contribution["data"]["adsorbateSmiles"]
 
         contribution_data = {
             "Bulk Formula": unicodeify(contribution["data"]["bulkFormula"]),
@@ -448,7 +438,7 @@ class CatalysisApp(MPApp):
                 contribution["data"]["mpid"],
                 href=f'/materials/{contribution["data"]["mpid"]}',
             ),
-            "Adsorbate SMILES": contribution["data"]["adsorbateSmiles"],
+            "Adsorbate SMILES": adsorbate_smiles,
             "Adsorbate IUPAC Formula": contribution["data"]["adsorbateIUPACFormula"],
             "Adsorption Energy": contribution["data"]["adsorptionEnergy"]["value"],
             "Miller Index": unicodeify_spacegroup(
@@ -474,9 +464,7 @@ class CatalysisApp(MPApp):
 
         return ctl.Container(
             [
-                ctl.H2(
-                    f'{unicodeify(contribution["data"]["adsorbateSmiles"])} on {unicodeify(contribution["data"]["bulkFormula"])}'
-                ),
+                ctl.H2(f"{unicodeify(adsorbate_smiles)} on {unicodeify(bulk_formula)}"),
                 ctl.H4(f"OCP ID: {payload}", subtitle=True),
                 ctl.Columns(
                     [
@@ -502,4 +490,4 @@ if __name__ == "__main__":
     # edit payload here to run for a specific OCP id, e.g. payload="random1222473"
     layout = ctl.Section([section.get_layout(payload=None)])
     ctc.register_crystal_toolkit(app=app, layout=layout, cache=None)
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
