@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import dash
 from dash import html
 from pymatgen.ext.matproj import MPRester
@@ -34,6 +36,6 @@ ctc.register_crystal_toolkit(app=app, layout=my_layout)
 
 # run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
-# see Dash documentation for more information
+# see Dash docs for more info
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
