@@ -1,7 +1,8 @@
+from __future__ import annotations
+
 import dash
 from dash import html
-from pymatgen.core.lattice import Lattice
-from pymatgen.core.structure import Structure
+from pymatgen.core import Lattice, Structure
 
 import crystal_toolkit.components as ctc
 from crystal_toolkit.settings import SETTINGS
@@ -43,6 +44,6 @@ ctc.register_crystal_toolkit(app, layout=my_layout)
 
 # run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
-# see Dash documentation for more information
+# see Dash docs for more info
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
