@@ -1,7 +1,12 @@
+from __future__ import annotations
+
 import time
+from typing import TYPE_CHECKING
 
 from crystal_toolkit.apps.examples.bandstructure import app
-from crystal_toolkit.apps.examples.tests.typing import DashDuo
+
+if TYPE_CHECKING:
+    from crystal_toolkit.apps.examples.tests.typing import DashDuo
 
 
 def test_bs(dash_duo: DashDuo) -> None:
