@@ -1,9 +1,14 @@
+from __future__ import annotations
+
 from time import sleep
+from typing import TYPE_CHECKING
 
 from selenium.webdriver.common.keys import Keys
 
 from crystal_toolkit.apps.examples.diffraction import app
-from crystal_toolkit.apps.examples.tests.typing import DashDuo
+
+if TYPE_CHECKING:
+    from crystal_toolkit.apps.examples.tests.typing import DashDuo
 
 
 def test_diffraction(dash_duo: DashDuo) -> None:
