@@ -1,9 +1,14 @@
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+
 from crystal_toolkit.apps.examples.fermi_surface import app
-from crystal_toolkit.apps.examples.tests.typing import DashDuo
+
+if TYPE_CHECKING:
+    from crystal_toolkit.apps.examples.tests.typing import DashDuo
 
 
 def test_diffraction(dash_duo: DashDuo) -> None:
-
     dash_duo.start_server(app)
     dash_duo.clear_storage()
 
