@@ -1,5 +1,7 @@
 # This example is used to write structures to images in an automated manner.
 # It is a very specific script! Not intended for general use.
+from __future__ import annotations
+
 import urllib
 from pathlib import Path
 from time import sleep
@@ -35,43 +37,42 @@ def get_structure_for_mpid(mpid):
     with MPRester() as mpr:
         structure = mpr.get_structure_by_material_id(mpid)
 
-    structure = SpacegroupAnalyzer(structure).get_conventional_standard_structure()
-    return structure
+    return SpacegroupAnalyzer(structure).get_conventional_standard_structure()
 
 
 @app.callback(
     Output(structure_component.id("scene"), "imageRequest"),
-    [Input(structure_component.id("graph"), "data")],
+    Input(structure_component.id("graph"), "data"),
 )
 def trigger_image_request(data):
     sleep(1)
     return {"filetype": "png"}
 
 
-@app.callback(Output(structure_component.id(), "data"), [Input("url", "pathname")])
+@app.callback(Output(structure_component.id(), "data"), Input("url", "pathname"))
 def trigger_new_data(url):
     mp_id = url[1:]
     with MPRester() as mpr:
         structure = mpr.get_structure_by_material_id(mp_id)
 
-    structure = SpacegroupAnalyzer(structure).get_conventional_standard_structure()
-    return structure
+    return SpacegroupAnalyzer(structure).get_conventional_standard_structure()
 
 
 @app.callback(
     Output("dummy-output", "children"),
-    [Input(structure_component.id("scene"), "imageDataTimestamp")],
-    [State("url", "pathname"), State(structure_component.id("scene"), "imageData")],
+    Input(structure_component.id("scene"), "imageDataTimestamp"),
+    State("url", "pathname"),
+    State(structure_component.id("scene"), "imageData"),
 )
 def save_image(image_data_timestamp, url, image_data):
     if image_data:
-        #     print(image_data.strip("data:image/png;base64,")[-1:-100])
-        #     image_bytes = b64decode(image_data.strip("data:image/png;base64,").encode('ascii'))
+        # print(image_data.strip("data:image/png;base64,")[-1:-100])
+        # image_bytes = b64decode(image_data.strip("data:image/png;base64,").encode('ascii'))
         response = urllib.request.urlopen(image_data)
-        with open(SCREENSHOT_PATH / f"{url[1:]}.png", "wb") as f:
-            f.write(response.file.read())
+        with open(SCREENSHOT_PATH / f"{url[1:]}.png", "wb") as file:
+            file.write(response.file.read())
 
 
 ctc.register_crystal_toolkit(app=app, layout=my_layout)
 if __name__ == "__main__":
-    app.run_server(debug=True, port=8050)
+    app.run(debug=True, port=8050)
