@@ -5,7 +5,7 @@ import os
 import warnings
 from random import choice
 from time import time
-from typing import Any
+from typing import TYPE_CHECKING, Any
 from urllib import parse
 from uuid import uuid4
 
@@ -22,7 +22,6 @@ from pymatgen.ext.matproj import MPRester, MPRestError
 import crystal_toolkit.components as ctc
 from crystal_toolkit import __file__ as module_path
 from crystal_toolkit.core.mpcomponent import MPComponent
-from crystal_toolkit.core.panelcomponent import PanelComponent
 from crystal_toolkit.helpers.layouts import (
     Box,
     Column,
@@ -36,6 +35,9 @@ from crystal_toolkit.helpers.layouts import (
 )
 from crystal_toolkit.settings import SETTINGS
 
+if TYPE_CHECKING:
+    from crystal_toolkit.core.panelcomponent import PanelComponent
+
 # choose a default structure on load
 path = os.path.join(os.path.dirname(module_path), "apps/assets/task_ids_on_load.json")
 DEFAULT_MPIDS = loadfn(path)
@@ -109,7 +111,7 @@ else:
         app.server,
         config={
             "CACHE_TYPE": "redis",
-            "CACHE_REDIS_URL": os.environ.get("REDIS_URL", SETTINGS.REDIS_URL),
+            "CACHE_REDIS_URL": os.getenv("REDIS_URL", SETTINGS.REDIS_URL),
         },
     )
 
@@ -173,18 +175,12 @@ if SETTINGS.MP_EMBED_MODE:
 else:
     action_div = html.Div([struct_component.download_layout()])
 
-panels = [
-    symmetry_panel,
-    localenv_panel,
-    xrd_panel,
-    robocrys_panel,
-]
+panels = [symmetry_panel, localenv_panel, xrd_panel, robocrys_panel]
 
 
 if SETTINGS.MP_EMBED_MODE:
     mp_section: tuple[Any, ...] = (html.Div(),)
 else:
-
     # bsdos_component = ctc.BandstructureAndDosPanelComponent(
     #     origin_component=search_component
     # )
@@ -304,7 +300,7 @@ footer = html.Footer(
 panel_choices = dcc.Dropdown(
     options=[{"label": panel.title, "value": idx} for idx, panel in enumerate(panels)],
     multi=True,
-    value=[idx for idx in range(len(panels))],
+    value=list(range(len(panels))),
     id="panel-choices",
 )
 
@@ -367,7 +363,7 @@ master_layout = Container(
                                 html.Div(
                                     [
                                         html.Div(
-                                            struct_component.legend_layout(),
+                                            struct_component._sub_layouts["legend"],
                                             style={"float": "left"},
                                         ),
                                         html.Div(
@@ -397,13 +393,13 @@ master_layout = Container(
                                     id="load",
                                 ),
                                 Reveal(
-                                    [struct_component.options_layout()],
+                                    [struct_component._sub_layouts["options"]],
                                     title="Display Options",
                                     id="display-options",
                                 ),
                                 action_div,
                             ],
-                            style={"width": box_size, "max-width": box_size},
+                            style={"width": box_size, "maxWidth": box_size},
                         ),
                     ],
                     desktop_only=False,
@@ -426,39 +422,36 @@ ctc.register_crystal_toolkit(layout=master_layout, app=app, cache=cache)
 ################################################################################
 
 
-@app.callback(Output(search_component.id("input"), "value"), [Input("url", "href")])
+@app.callback(Output(search_component.id("input"), "value"), Input("url", "href"))
 def update_search_term_on_page_load(href: str) -> str:
-    """If an mpid is provided in the url, load that mpid. Otherwise load a random mpid from the
+    """If an MP ID is provided in the url, load that MP ID. Otherwise load a random MP ID from the
     DEFAULT_MPIDS global variable.
 
     Args:
         href: e.g. "http://localhost:8050/mp-11358"
 
-    Returns: an mpid
+    Returns: an MP ID
     """
     if href is None:
         raise PreventUpdate
     pathname = str(parse.urlparse(href).path).split("/")
     if len(pathname) <= 1:
         raise PreventUpdate
-    elif not pathname[1]:
+    if not pathname[1]:
         return choice(DEFAULT_MPIDS)
-    else:
-        return pathname[1].replace("+", " ")
+    return pathname[1].replace("+", " ")
 
 
 @app.callback(
-    [
-        Output(search_component.id("input"), "n_submit"),
-        Output(search_component.id("input"), "n_submit_timestamp"),
-    ],
-    [Input(search_component.id("input"), "value")],
-    [State(search_component.id("input"), "n_submit")],
+    Output(search_component.id("input"), "n_submit"),
+    Output(search_component.id("input"), "n_submit_timestamp"),
+    Input(search_component.id("input"), "value"),
+    State(search_component.id("input"), "n_submit"),
 )
 def perform_search_on_page_load(
     search_term: str, n_submit: int | None
 ) -> tuple[int, int]:
-    """Loading with an mpid in the URL requires populating the search term with the mpid, this
+    """Loading with an MP ID in the URL requires populating the search term with the MP ID, this
     callback forces that search to then take place by force updating n_submit and n_submit_timestamp
     props.
 
@@ -471,11 +464,10 @@ def perform_search_on_page_load(
     # TODO: could be a client side callback
     if n_submit is None:
         return 1, int(round(time() * 1000))
-    else:
-        raise PreventUpdate
+    raise PreventUpdate
 
 
-@app.callback(Output("url", "pathname"), [Input(search_component.id(), "data")])
+@app.callback(Output("url", "pathname"), Input(search_component.id(), "data"))
 def update_url_pathname_from_search_term(mpid: str | None) -> str:
     """Updates the URL from the search term. Technically a circular callback, this is done to
     prevent the app seeming inconsistent from the end user.
@@ -493,7 +485,8 @@ def update_url_pathname_from_search_term(mpid: str | None) -> str:
 
 @app.callback(
     Output(transformation_component.id("input_structure"), "data"),
-    [Input(search_component.id(), "data"), Input(upload_component.id(), "data")],
+    Input(search_component.id(), "data"),
+    Input(upload_component.id(), "data"),
 )
 def master_update_structure(
     search_mpid: str | None, upload_data: dict | None
@@ -508,19 +501,18 @@ def master_update_structure(
 
     Returns: an encoded Structure
     """
-
     if not search_mpid and not upload_data:
         raise PreventUpdate
 
     if not dash.callback_context.triggered:
         raise PreventUpdate
 
-    if len(dash.callback_context.triggered) > 1:
-        # triggered by both on initial load
-        load_by = "mpid"
-    elif (
-        dash.callback_context.triggered[0]["prop_id"] == f"{search_component.id()}.data"
+    if (
+        len(dash.callback_context.triggered) > 1
+        or dash.callback_context.triggered[0]["prop_id"]
+        == f"{search_component.id()}.data"
     ):
+        # triggered by both on initial load
         load_by = "mpid"
     else:
         load_by = "uploaded"
@@ -528,7 +520,6 @@ def master_update_structure(
     upload_data = upload_data or {}
 
     if load_by == "mpid":
-
         if search_mpid is None:
             raise PreventUpdate
 
@@ -541,7 +532,6 @@ def master_update_structure(
                 struct = mpr.get_structure_by_material_id(search_mpid)
                 print("Struct from material.")
     else:
-
         struct = MPComponent.from_data(upload_data["data"])
 
     return struct
@@ -555,4 +545,4 @@ def master_update_structure(
 
 
 if __name__ == "__main__":
-    app.run_server(debug=SETTINGS.DEBUG_MODE, port=8051)
+    app.run(debug=SETTINGS.DEBUG_MODE, port=8051)
