@@ -1,19 +1,31 @@
 from __future__ import annotations
 
 import math
+from typing import TYPE_CHECKING
 
 import numpy as np
-import plotly.graph_objs as go
+import plotly.graph_objects as go
 from dash import callback_context, dcc, html
-from dash.dependencies import Input, Output
+from dash.dependencies import Component, Input, Output
 from dash.exceptions import PreventUpdate
-from pymatgen.analysis.diffraction.tem import TEMCalculator
+from frozendict import frozendict
 from pymatgen.analysis.diffraction.xrd import WAVELENGTHS, XRDCalculator
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from scipy.special import wofz
 
 from crystal_toolkit.core.mpcomponent import MPComponent
-from crystal_toolkit.helpers.layouts import Box, Column, Columns, Loading
+from crystal_toolkit.helpers.layouts import (
+    Box,
+    Column,
+    Columns,
+    Loading,
+    MessageBody,
+    MessageContainer,
+)
+
+if TYPE_CHECKING:
+    from pymatgen.core import Structure
+
 
 # Scherrer equation: Langford, J. Il, and A. J. C. Wilson. "Scherrer after sixty years:
 # a survey and some new results in the determination of crystallite size." Journal of
@@ -29,76 +41,20 @@ from crystal_toolkit.helpers.layouts import Box, Column, Columns, Loading
 # Author: Matthew McDermott
 # Contact: mcdermott@lbl.gov
 
-
-class TEMDiffractionComponent(MPComponent):
-    def __init__(self, *args, initial_structure=None, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.create_store("structure", initial_data=initial_structure)
-
-    def layout(self) -> Columns:
-
-        voltage = self.get_numerical_input(
-            kwarg_label="voltage",
-            default=200,
-            label="Voltage / kV",
-            help_str="The incident wavelength with which to generate the diffraction pattern, "
-            "typically corresponding to a TEM microscope’s voltage.",
-        )
-
-        beam_direction = self.get_numerical_input(
-            kwarg_label="beam_direction",
-            default=[0, 0, 1],
-            label="Beam Direction",
-            help_str="The direction of the electron beam fired onto the sample.",
-            shape=(3,),
-            is_int=True,
-        )
-
-        # TODO: add additional kwargs for TemCalculator, or switch to an alternative solution
-
-        return Columns(
-            [
-                Column([Box(Loading(id=self.id("tem-plot")))], size=8),
-                Column(
-                    [voltage, html.Br(), beam_direction],
-                    size=4,
-                ),
-            ],
-        )
-
-    def generate_callbacks(self, app, cache):
-        @app.callback(
-            Output(self.id("tem-plot"), "children"),
-            [
-                Input(self.id("structure"), "data"),
-                Input(self.get_all_kwargs_id(), "value"),
-            ],
-        )
-        def generate_diffraction_pattern(structure, *args):
-
-            structure = self.from_data(structure)
-            kwargs = self.reconstruct_kwargs_from_state()
-
-            calculator = TEMCalculator(**kwargs)
-
-            print("kwargs", kwargs)
-
-            return dcc.Graph(
-                figure=calculator.get_plot_2d(structure),
-                responsive=False,
-                config=dict(displayModeBar=False, displaylogo=False),
-            )
+SITES_LIMIT = 25
 
 
 class XRayDiffractionComponent(MPComponent):
     # TODO: add pole figures for a given single peak for help quantifying texture
 
-    def __init__(self, *args, initial_structure=None, **kwargs):
+    def __init__(
+        self, *args, initial_structure: Structure | None = None, **kwargs
+    ) -> None:
         super().__init__(*args, **kwargs)
         self.create_store("structure", initial_data=initial_structure)
 
     # Default XRD plot style settings
-    default_xrd_plot_style = dict(
+    default_xrd_plot_style = frozendict(
         xaxis={
             "title": "2𝜃 / º",
             "anchor": "y",
@@ -136,12 +92,12 @@ class XRayDiffractionComponent(MPComponent):
         template="simple_white",
     )
 
-    empty_plot_style = {
-        "xaxis": {"visible": False},
-        "yaxis": {"visible": False},
-        "paper_bgcolor": "rgba(0,0,0,0)",
-        "plot_bgcolor": "rgba(0,0,0,0)",
-    }
+    empty_plot_style = frozendict(
+        xaxis={"visible": False},
+        yaxis={"visible": False},
+        paper_bgcolor="rgba(0,0,0,0)",
+        plot_bgcolor="rgba(0,0,0,0)",
+    )
 
     @staticmethod
     def G(x, c, alpha):
@@ -187,7 +143,8 @@ class XRayDiffractionComponent(MPComponent):
     def grain_to_hwhm(
         tau: float, two_theta: float, K: float = 0.9, wavelength: float | str = "CuKa"
     ) -> float:
-        """_summary_
+        """Calculate the half-width half-max (alpha or gamma) for a given grain size and
+        angle.
 
         Args:
             tau (float): grain size in nm
@@ -205,8 +162,7 @@ class XRayDiffractionComponent(MPComponent):
         return 0.5 * K * 0.1 * wavelength / (tau * abs(np.cos(two_theta / 2)))
 
     @property
-    def _sub_layouts(self):
-
+    def _sub_layouts(self) -> dict[str, Component]:
         state = {
             "peak_profile": "G",
             "shape_factor": 0.94,
@@ -219,7 +175,9 @@ class XRayDiffractionComponent(MPComponent):
         graph = Loading(
             [
                 dcc.Graph(
-                    figure=go.Figure(layout=XRayDiffractionComponent.empty_plot_style),
+                    figure=go.Figure(
+                        layout={**XRayDiffractionComponent.empty_plot_style}
+                    ),
                     id=self.id("xrd-plot"),
                     config={
                         "displayModeBar": False,  # or "hover",
@@ -249,7 +207,7 @@ class XRayDiffractionComponent(MPComponent):
             help_str="This defines the wavelength of the incident X-ray radiation.",
             options=[
                 {
-                    "label": f'{name.replace("a", "α").replace("b", "β")} ({wavelength:.3f} Å)',
+                    "label": f'{name.replace("a", "α").replace("b", "β")} ({wavelength:.3f} Å)',  # noqa: RUF001
                     "value": name,
                 }
                 for name, wavelength in WAVELENGTHS.items()
@@ -295,7 +253,7 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
                 self.get_choice_input(
                     kwarg_label="x_axis",
                     state=state,
-                    label="Choice of 𝑥 axis",
+                    label="Choice of x axis",
                     help_str="Can choose between 2𝜃 or Q, where Q is the magnitude of the reciprocal lattice and "
                     "independent of radiation source.",  # TODO: improve
                     options=[
@@ -345,10 +303,7 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
             Columns: from crystal_toolkit.helpers.layouts
         """
         sub_layouts = self._sub_layouts
-        if static_image:
-            inner = sub_layouts["static_image"]
-        else:
-            inner = sub_layouts["graph"]
+        inner = sub_layouts["static_image"] if static_image else sub_layouts["graph"]
 
         return Columns(
             [
@@ -364,6 +319,13 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
                         sub_layouts["shape_factor"],
                         sub_layouts["peak_profile"],
                         sub_layouts["crystallite_size"],
+                        html.Div(
+                            id=self.id("large_cell_note"),
+                            style={
+                                "marginTop": "20px",
+                                "marginRight": "10px",
+                            },
+                        ),
                     ],
                     size=4,
                 ),
@@ -372,13 +334,20 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
 
     @staticmethod
     def get_figure(
-        peak_profile, K, rad_source, grain_size, x_peak, y_peak, d_hkls, hkls, x_axis
-    ):
-
+        peak_profile,
+        K,
+        rad_source,
+        grain_size,
+        x_peak,
+        y_peak,
+        d_hkls,
+        hkls,
+        x_axis,
+        broadening=True,
+    ) -> go.Figure:
         hkl_list = [hkl[0]["hkl"] for hkl in hkls]
-        hkls = [
-            f"hkl: ({' '.join([str(i) for i in hkl])})" for hkl in hkl_list
-        ]  # convert to (h k l) format
+        # convert to (h k l) format
+        hkls = [f"hkl: ({' '.join(map(str, hkl))})" for hkl in hkl_list]
 
         annotations = [
             f"2𝜃: {round(peak_x, 3)}<br>Intensity: {round(peak_y, 3)}<br>{hkl} <br>d: {round(d, 3)}"
@@ -393,39 +362,36 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
         num_sigma = {"G": 5, "L": 12, "V": 12}[peak_profile]
 
         # optimal number of points per degree determined through usage experiments
-        if grain_size > 10:
-            # scaled to log size to the 4th power
-            N_density = 150 * (math.log10(grain_size) ** 4)
-        else:
-            N_density = 150
+        # scaled to log size to the 4th power
+        N_density = 150 * (math.log10(grain_size) ** 4) if grain_size > 10 else 150
 
         N = int(N_density * domain)  # num total points
+
         x = np.linspace(first, last, N).tolist()
         y = np.zeros(len(x)).tolist()
 
-        for xp, yp in zip(x_peak, y_peak):
-            alpha = XRayDiffractionComponent.grain_to_hwhm(
-                grain_size, math.radians(xp / 2), K=float(K), wavelength=rad_source
-            )
-            sigma = (alpha / np.sqrt(2 * np.log(2))).item()
-
-            center_idx = int(round((xp - first) * N_density))
-            half_window = int(
-                round(num_sigma * sigma * N_density)
-            )  # i.e. total window of 2 * num_sigma
-
-            lb = max([0, (center_idx - half_window)])
-            ub = min([N, (center_idx + half_window)])
-
-            G0 = getattr(XRayDiffractionComponent, peak_profile)(0, 0, alpha)
-            for i, j in zip(range(lb, ub), range(lb, ub)):
-                y[j] += (
-                    yp
-                    * getattr(XRayDiffractionComponent, peak_profile)(x[i], xp, alpha)
-                    / G0
+        if broadening:
+            for xp, yp in zip(x_peak, y_peak):
+                alpha = XRayDiffractionComponent.grain_to_hwhm(
+                    grain_size, math.radians(xp / 2), K=float(K), wavelength=rad_source
                 )
+                sigma = (alpha / np.sqrt(2 * np.log(2))).item()
 
-        layout = XRayDiffractionComponent.default_xrd_plot_style
+                center_idx = int(round((xp - first) * N_density))
+                # total broadening window of 2 * num_sigma
+                half_window = int(round(num_sigma * sigma * N_density))
+
+                lb = max(0, (center_idx - half_window))
+                ub = min(N, (center_idx + half_window))
+
+                G0 = getattr(XRayDiffractionComponent, peak_profile)(0, 0, alpha)
+                for ii, jj in zip(range(lb, ub), range(lb, ub)):
+                    Gi = getattr(XRayDiffractionComponent, peak_profile)(
+                        x[ii], xp, alpha
+                    )
+                    y[jj] += yp * Gi / G0
+
+        layout = {**XRayDiffractionComponent.default_xrd_plot_style}
 
         if x_axis == "Q":
             x_peak = XRayDiffractionComponent.two_theta_to_q(
@@ -438,7 +404,7 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
         layout["xaxis"]["range"] = [min(x), max(x)]
         bar_width = 0.003 * (max(x) - min(x))  # set width of bars to 0.5% of the domain
 
-        plotdata = [
+        plot_data = [
             go.Bar(
                 x=x_peak,
                 y=y_peak,
@@ -447,14 +413,14 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
                 text=annotations,
                 opacity=0.8,
                 marker={"color": "black"},
-            ),
-            go.Scatter(x=x, y=y, hoverinfo="none"),
+            )
         ]
-        plot = go.Figure(data=plotdata, layout=layout)
+        if broadening:
+            plot_data.append(go.Scatter(x=x, y=y, hoverinfo="none"))
 
-        return plot
+        return go.Figure(data=plot_data, layout=layout)
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         @app.callback(
             Output(self.id("xrd-plot"), "figure"),
             [
@@ -464,10 +430,12 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
                 Input(self.get_kwarg_id("peak_profile"), "value"),
                 Input(self.get_kwarg_id("shape_factor"), "value"),
                 Input(self.get_kwarg_id("x_axis"), "value"),
+                Input(self.id("structure"), "data"),
             ],
         )
-        def update_graph(data, logsize, rad_source, peak_profile, K, x_axis):
-
+        def update_graph(
+            data, log_size, rad_source, peak_profile, K, x_axis, structure
+        ):
             if not data:
                 raise PreventUpdate
 
@@ -479,16 +447,18 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
             peak_profile = kwargs["peak_profile"]
             K = kwargs["shape_factor"]
             rad_source = kwargs["rad_source"]
-            logsize = float(kwargs["crystallite_size"])
+            log_size = float(kwargs["crystallite_size"])
             x_axis = kwargs["x_axis"]
 
-            grain_size = 10**logsize
+            grain_size = 10**log_size
             x_peak = data["x"]
             y_peak = data["y"]
             d_hkls = data["d_hkls"]
             hkls = data["hkls"]
+            # suppress broadening for larger cell
+            broadening = len(self.from_data(structure).sites) < SITES_LIMIT
 
-            plot = self.get_figure(
+            return self.get_figure(
                 peak_profile,
                 K,
                 rad_source,
@@ -498,10 +468,9 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
                 d_hkls,
                 hkls,
                 x_axis,
+                broadening,
             )
 
-            return plot
-
         @app.callback(
             Output(self.id(), "data"),
             [
@@ -510,7 +479,6 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
             ],
         )
         def pattern_from_struct(struct, rad_source):
-
             if struct is None or not rad_source:
                 raise PreventUpdate
 
@@ -521,25 +489,37 @@ crystals in a spherical shape is used. However, in practice K can vary from 0.62
             )
 
             sga = SpacegroupAnalyzer(struct)
-            struct = (
-                sga.get_conventional_standard_structure()
-            )  # always get conventional structure
+            # always get conventional structure
+            struct = sga.get_conventional_standard_structure()
 
-            xrdc = XRDCalculator(
+            xrd_calc = XRDCalculator(
                 wavelength=WAVELENGTHS[rad_source], symprec=0, debye_waller_factors=None
             )
-            data = xrdc.get_pattern(struct, two_theta_range=None)
+            data = xrd_calc.get_pattern(struct, two_theta_range=None)
 
             return data.as_dict()
 
+        @app.callback(
+            Output(self.id("large_cell_note"), "children"),
+            Input(self.id("structure"), "data"),
+        )
+        def update_message(structure):
+            if len(self.from_data(structure).sites) < SITES_LIMIT:
+                return html.Div([])
+            return MessageContainer(
+                MessageBody(
+                    "Peak broadening is currently disabled for materials with "
+                    f"more than {SITES_LIMIT} sites due to long compute time. Please contact "
+                    "feedback@materialsproject.org if you need assistance with the graph."
+                )
+            )
+
         # @app.callback(
-        #     Output(self.id("static-image"), "src"),
-        #     [Input(self.id("xrd-plot"), "figure")]
+        #     Output(self.id("static-image"), "src"), Input(self.id("xrd-plot"), "figure")
         # )
         # def update_static_image(data):
-        #
         #     scope = PlotlyScope()
         #     output = scope.transform(data, format="png", width=600, height=400, scale=4)
-        #     image = b64encode(output).decode('ascii')
-        #
+        #     image = b64encode(output).decode("ascii")
+
         #     return f"data:image/png;base64,{image}"
