@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import itertools
 from multiprocessing import cpu_count
 from warnings import warn
@@ -20,7 +22,7 @@ from pymatgen.analysis.chemenv.coordination_environments.structure_environments
 )
 from pymatgen.analysis.graphs import MoleculeGraph, StructureGraph
 from pymatgen.analysis.local_env import LocalStructOrderParams, cn_opt_params
-from pymatgen.core.structure import Molecule, Structure
+from pymatgen.core import Molecule, Structure
 from pymatgen.ext.matproj import MPRester
 from pymatgen.io.ase import AseAtomsAdaptor
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
@@ -37,7 +39,7 @@ from crystal_toolkit.helpers.layouts import (
     Label,
     Loading,
     cite_me,
-    get_data_list,
+    get_table,
     get_tooltip,
 )
 
@@ -45,7 +47,7 @@ try:
     from dscribe.descriptors import SOAP
     from dscribe.kernels import REMatchKernel
 except ImportError:
-    warn(
+    no_soap_msg = (
         "Using dscribe SOAP and REMatchKernel requires the dscribe package "
         "which was made optional since it in turn requires numba and numba "
         "was a common source of installation issues."
@@ -62,6 +64,7 @@ def _get_local_order_parameters(structure_graph, n):
     underlying motif (e.g., CN=4, then calculate the
     square planar, tetrahedral, see-saw-like,
     rectangular see-saw-like order parameters).
+
     Args:
         structure_graph: StructureGraph object
         n (int): site index.
@@ -75,7 +78,7 @@ def _get_local_order_parameters(structure_graph, n):
     # import, also makes sense to have this as a general NN method
     cn = structure_graph.get_coordination_of_site(n)
     if cn in [int(k_cn) for k_cn in cn_opt_params]:
-        names = [k for k in cn_opt_params[cn]]
+        names = list(cn_opt_params[cn])
         types = []
         params = []
         for name in names:
@@ -84,24 +87,25 @@ def _get_local_order_parameters(structure_graph, n):
                 cn_opt_params[cn][name][1] if len(cn_opt_params[cn][name]) > 1 else None
             )
             params.append(tmp)
-        lostops = LocalStructOrderParams(types, parameters=params)
+        lost_ops = LocalStructOrderParams(types, parameters=params)
         sites = [structure_graph.structure[n]] + [
             connected_site.site
             for connected_site in structure_graph.get_connected_sites(n)
         ]
-        lostop_vals = lostops.get_order_parameters(
-            sites, 0, indices_neighs=[i for i in range(1, cn + 1)]
+        lost_op_vals = lost_ops.get_order_parameters(
+            sites, 0, indices_neighs=list(range(1, cn + 1))
         )
         d = {}
-        for i, lostop in enumerate(lostop_vals):
-            d[names[i]] = lostop
+        for idx, lost_op in enumerate(lost_op_vals):
+            d[names[idx]] = lost_op
         return d
-    else:
-        return None
+    return None
 
 
 class LocalEnvironmentPanel(PanelComponent):
-    def __init__(self, *args, **kwargs):
+    """A panel to analyze the local chemical environments in a crystal."""
+
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.create_store("graph")
         self.create_store(
@@ -110,19 +114,22 @@ class LocalEnvironmentPanel(PanelComponent):
         )
 
     @property
-    def title(self):
+    def title(self) -> str:
+        """Title of the panel."""
         return "Local Environments"
 
     @property
-    def description(self):
+    def description(self) -> str:
+        """Description of the panel."""
         return "Analyze the local chemical environments in your crystal."
 
     @property
     def loading_text(self):
+        """Text to display while loading."""
         return "Analyzing environments"
 
     def contents_layout(self) -> html.Div:
-
+        """HTML layout of the panel contents."""
         algorithm_choices = self.get_choice_input(
             label="Analysis method",
             kwarg_label="algorithm",
@@ -143,7 +150,7 @@ class LocalEnvironmentPanel(PanelComponent):
 
     @staticmethod
     def get_graph_data(graph, display_options):
-
+        """Get the data for the graph visualization."""
         color_scheme = display_options.get("color_scheme", "Jmol")
 
         nodes = []
@@ -153,7 +160,6 @@ class LocalEnvironmentPanel(PanelComponent):
         legend = Legend(struct_or_mol, color_scheme=color_scheme)
 
         for idx, node in enumerate(graph.graph.nodes()):
-
             # TODO: fix for disordered
             node_color = legend.get_color(
                 struct_or_mol[node].species.elements[0], site=struct_or_mol[node]
@@ -169,7 +175,6 @@ class LocalEnvironmentPanel(PanelComponent):
             )
 
         for u, v, d in graph.graph.edges(data=True):
-
             edge = {"from": u, "to": v, "arrows": ""}
 
             to_jimage = d.get("to_jimage", (0, 0, 0))
@@ -197,22 +202,20 @@ class LocalEnvironmentPanel(PanelComponent):
 
         return {"nodes": nodes, "edges": edges}
 
-    def generate_callbacks(self, app, cache):
-
+    def generate_callbacks(self, app, cache) -> None:
+        """Generate the callbacks for the panel interactions."""
         super().generate_callbacks(app, cache)
 
         @app.callback(
             Output(self.id("analysis"), "children"),
-            [Input(self.get_kwarg_id("algorithm"), "value")],
+            Input(self.get_kwarg_id("algorithm"), "value"),
         )
         def run_algorithm(algorithm):
-
             algorithm = self.reconstruct_kwarg_from_state(
                 callback_context.inputs, "algorithm"
             )
 
             if algorithm == "chemenv":
-
                 state = {"distance_cutoff": 1.4, "angle_cutoff": 0.3}
 
                 description = (
@@ -258,8 +261,7 @@ class LocalEnvironmentPanel(PanelComponent):
                     ]
                 )
 
-            elif algorithm == "localenv":
-
+            if algorithm == "localenv":
                 description = (
                     "The LocalEnv algorithm is developed by Nils Zimmerman et al. whereby "
                     "an 'order parameter' is calculated that measures how well that "
@@ -280,8 +282,7 @@ class LocalEnvironmentPanel(PanelComponent):
                     ]
                 )
 
-            elif algorithm == "bondinggraph":
-
+            if algorithm == "bondinggraph":
                 description = (
                     "This is an alternative way to display the same bonds present in the "
                     "visualizer. Here, the bonding is displayed as a crystal graph, with "
@@ -297,15 +298,14 @@ class LocalEnvironmentPanel(PanelComponent):
                     ]
                 )
 
-            elif algorithm == "soap":
-
+            if algorithm == "soap":
                 state = {
                     "rcut": 5.0,
                     "nmax": 2,
                     "lmax": 2,
                     "sigma": 0.2,
                     "crossover": True,
-                    "average": False,
+                    "average": "off",
                     "rbf": "gto",
                     "alpha": 0.1,
                     "threshold": 1e-4,
@@ -385,11 +385,23 @@ class LocalEnvironmentPanel(PanelComponent):
                     help_str="If enabled, the power spectrum will include all combinations of elements present.",
                 )
 
-                average = self.get_bool_input(
+                average = self.get_choice_input(
                     label="Average",
                     kwarg_label="average",
                     state=state,
-                    help_str="If enabled, the SOAP vector will be averaged across all sites.",
+                    help_str="The averaging mode over the centers of interest",
+                    options=[
+                        {"label": "No averaging", "value": "off"},
+                        {
+                            "label": "Inner: Averaging over sites before summing up the magnetic quantum numbers",
+                            "value": "inner",
+                        },
+                        {
+                            "label": "Outer: Averaging over the power spectrum of different sites",
+                            "value": "outer",
+                        },
+                    ],
+                    style={"width": "16rem"},  # TODO: remove in-line style
                 )
 
                 alpha = self.get_numerical_input(
@@ -432,7 +444,7 @@ class LocalEnvironmentPanel(PanelComponent):
                     style={"width": "16rem"},  # TODO: remove in-line style
                 )
 
-                normalize_kernel = self.get_bool_input(
+                _normalize_kernel = self.get_bool_input(
                     label="Normalize",
                     kwarg_label="normalize_kernel",
                     state=state,
@@ -474,9 +486,9 @@ class LocalEnvironmentPanel(PanelComponent):
                         Loading(id=self.id("soap_similarities")),
                     ]
                 )
+            return None
 
         def _get_soap_graph(feature, label):
-
             spectrum = {
                 "data": [
                     {
@@ -529,14 +541,15 @@ class LocalEnvironmentPanel(PanelComponent):
 
         @app.callback(
             Output(self.id("soap_analysis"), "children"),
-            [Input(self.id(), "data"), Input(self.get_all_kwargs_id(), "value")],
+            Input(self.id(), "data"),
+            Input(self.get_all_kwargs_id(), "value"),
         )
         def update_soap_analysis(struct, all_kwargs):
-
             if not struct:
                 raise PreventUpdate
 
             if not SOAP:
+                warn(no_soap_msg)
                 return mpc.Markdown(
                     "This feature will not work unless `dscribe` is installed on the server."
                 )
@@ -559,35 +572,40 @@ class LocalEnvironmentPanel(PanelComponent):
 
             adaptor = AseAtomsAdaptor()
             atoms = adaptor.get_atoms(struct)
-            feature = normalize(desc.create(atoms, n_jobs=cpu_count()))
+
+            # make a 2D vector even when it is averaged
+            soap_output = desc.create(atoms, n_jobs=cpu_count())
+            soap_output = soap_output.reshape((-1, soap_output.shape[-1]))
+            feature = normalize(soap_output)
 
             return _get_soap_graph(feature, "SOAP vector for this material")
 
         @cache.memoize(timeout=360)
         def _get_all_structs_from_elements(elements):
             structs = {}
-            all_chemsyses = []
-            for i in range(len(elements)):
-                for els in itertools.combinations(elements, i + 1):
-                    all_chemsyses.append("-".join(sorted(els)))
-
+            all_chemsys = [
+                "-".join(sorted(els))
+                for idx in range(len(elements))
+                for els in itertools.combinations(elements, idx + 1)
+            ]
             with MPRester() as mpr:
                 docs = mpr.query(
-                    {"chemsys": {"$in": all_chemsyses}}, ["task_id", "structure"]
+                    {"chemsys": {"$in": all_chemsys}}, ["task_id", "structure"]
                 )
             structs.update({d["task_id"]: d["structure"] for d in docs})
             return structs
 
         @app.callback(
             Output(self.id("soap_similarities"), "children"),
-            [Input(self.id(), "data"), Input(self.get_all_kwargs_id(), "value")],
+            Input(self.id(), "data"),
+            Input(self.get_all_kwargs_id(), "value"),
         )
         def update_soap_similarities(struct, all_kwargs):
-
             if not struct:
                 raise PreventUpdate
 
             if not SOAP:
+                warn(no_soap_msg)
                 return mpc.Markdown(
                     "This feature will not work unless `dscribe` is installed on the server."
                 )
@@ -623,10 +641,13 @@ class LocalEnvironmentPanel(PanelComponent):
             }
 
             print(f"Calculating {len(atomss)} SOAP vectors")
-            features = {
-                mpid: normalize(desc.create(atoms, n_jobs=cpu_count()))
-                for mpid, atoms in atomss.items()
-            }
+            features = {}
+            for mpid, atoms in atomss.items():
+                # make a 2D vector even when it is averaged
+                soap_output = desc.create(atoms, n_jobs=cpu_count())
+                soap_output = soap_output.reshape((-1, soap_output.shape[-1]))
+                feature = normalize(soap_output)
+                features[mpid] = feature
 
             re = REMatchKernel(
                 metric=kwargs["metric"],
@@ -667,10 +688,9 @@ class LocalEnvironmentPanel(PanelComponent):
 
         @app.callback(
             Output(self.id("localenv_analysis"), "children"),
-            [Input(self.id("graph"), "data")],
+            Input(self.id("graph"), "data"),
         )
         def update_localenv_analysis(graph):
-
             if not graph:
                 raise PreventUpdate
 
@@ -686,13 +706,10 @@ class LocalEnvironmentPanel(PanelComponent):
 
         @app.callback(
             Output(self.id("bondinggraph_analysis"), "children"),
-            [
-                Input(self.id("graph"), "data"),
-                Input(self.id("display_options"), "data"),
-            ],
+            Input(self.id("graph"), "data"),
+            Input(self.id("display_options"), "data"),
         )
         def update_bondinggraph_analysis(graph, display_options):
-
             if not graph:
                 raise PreventUpdate
 
@@ -727,14 +744,11 @@ class LocalEnvironmentPanel(PanelComponent):
 
         @app.callback(
             Output(self.id("chemenv_analysis"), "children"),
-            [
-                Input(self.id(), "data"),
-                Input(self.get_kwarg_id("distance_cutoff"), "value"),
-                Input(self.get_kwarg_id("angle_cutoff"), "value"),
-            ],
+            Input(self.id(), "data"),
+            Input(self.get_kwarg_id("distance_cutoff"), "value"),
+            Input(self.get_kwarg_id("angle_cutoff"), "value"),
         )
         def get_chemenv_analysis(struct, distance_cutoff, angle_cutoff):
-
             if not struct:
                 raise PreventUpdate
 
@@ -752,8 +766,7 @@ class LocalEnvironmentPanel(PanelComponent):
                 valences = [v for v in valences if v is not None]
                 if len(valences) == len(struct):
                     return valences
-                else:
-                    return "undefined"
+                return "undefined"
 
             # decide which indices to present to user
             sga = SpacegroupAnalyzer(struct)
@@ -783,11 +796,10 @@ class LocalEnvironmentPanel(PanelComponent):
             unknown_sites = []
 
             for index, wyckoff in zip(inequivalent_indices, wyckoffs):
-
-                datalist = {
-                    "Site": unicodeify_species(struct[index].species_string),
-                    "Wyckoff Label": wyckoff,
-                }
+                datalist = [
+                    ["Site", unicodeify_species(struct[index].species_string)],
+                    ["Wyckoff Label", wyckoff],
+                ]
 
                 if not lse.neighbors_sets[index]:
                     unknown_sites.append(f"{struct[index].species_string} ({wyckoff})")
@@ -795,7 +807,7 @@ class LocalEnvironmentPanel(PanelComponent):
 
                 # represent the local environment as a molecule
                 mol = Molecule.from_sites(
-                    [struct[index]] + lse.neighbors_sets[index][0].neighb_sites
+                    [struct[index], *lse.neighbors_sets[index][0].neighb_sites]
                 )
                 mol = mol.get_centered_molecule()
                 mg = MoleculeGraph.with_empty_graph(molecule=mol)
@@ -820,32 +832,34 @@ class LocalEnvironmentPanel(PanelComponent):
                 if co.alternative_names:
                     name += f" (also known as {', '.join(co.alternative_names)})"
 
-                datalist.update(
-                    {
-                        "Environment": name,
-                        "IUPAC Symbol": co.IUPAC_symbol_str,
-                        get_tooltip(
-                            "CSM",
-                            "The continuous symmetry measure (CSM) describes the similarity to an "
-                            "ideal coordination environment. It can be understood as a 'distance' to "
-                            "a shape and ranges from 0 to 100 in which 0 corresponds to a "
-                            "coordination environment that is exactly identical to the ideal one. A "
-                            "CSM larger than 5.0 already indicates a relatively strong distortion of "
-                            "the investigated coordination environment.",
-                        ): f"{env[0]['csm']:.2f}",
-                        "Interactive View": view,
-                    }
+                datalist.extend(
+                    [
+                        ["Environment", name],
+                        ["IUPAC Symbol", co.IUPAC_symbol_str],
+                        [
+                            get_tooltip(
+                                "CSM",
+                                "The continuous symmetry measure (CSM) describes the similarity to an "
+                                "ideal coordination environment. It can be understood as a 'distance' to "
+                                "a shape and ranges from 0 to 100 in which 0 corresponds to a "
+                                "coordination environment that is exactly identical to the ideal one. A "
+                                "CSM larger than 5.0 already indicates a relatively strong distortion of "
+                                "the investigated coordination environment.",
+                            ),
+                            f"{env[0]['csm']:.2f}",
+                        ],
+                        ["Interactive View", view],
+                    ]
                 )
 
-                envs.append(get_data_list(datalist))
+                envs.append(get_table(rows=datalist))
 
             # TODO: switch to tiles?
             envs_grouped = [envs[i : i + 2] for i in range(0, len(envs), 2)]
-            analysis_contents = []
-            for env_group in envs_grouped:
-                analysis_contents.append(
-                    Columns([Column(e, size=6) for e in env_group])
-                )
+            analysis_contents = [
+                Columns([Column(e, size=6) for e in env_group])
+                for env_group in envs_grouped
+            ]
 
             if unknown_sites:
                 unknown_sites = html.Strong(
