@@ -1,10 +1,13 @@
+from __future__ import annotations
+
 import re
 
 import numpy as np
-import plotly.graph_objs as go
+import plotly.graph_objects as go
 from dash import dcc, html
-from dash.dependencies import Input, Output, State
+from dash.dependencies import Component, Input, Output, State
 from dash.exceptions import PreventUpdate
+from frozendict import frozendict
 from pymatgen.analysis.pourbaix_diagram import ELEMENTS_HO, PREFAC, PourbaixDiagram
 from pymatgen.core import Composition
 from pymatgen.util.string import unicodeify
@@ -26,10 +29,9 @@ WIDTH = 700  # in px
 
 
 class PourbaixDiagramComponent(MPComponent):
+    default_state = frozendict(filter_solids=True, show_heatmap=False)
 
-    default_state = {"filter_solids": True, "show_heatmap": False}
-
-    default_plot_style = dict(
+    default_plot_style = frozendict(
         xaxis={
             "title": "pH",
             "anchor": "y",
@@ -75,37 +77,39 @@ class PourbaixDiagramComponent(MPComponent):
         margin=dict(l=80, b=70, t=10, r=20),
     )
 
-    empty_plot_style = {
-        "xaxis": {"visible": False},
-        "yaxis": {"visible": False},
-        "paper_bgcolor": "rgba(0,0,0,0)",
-        "plot_bgcolor": "rgba(0,0,0,0)",
-    }
+    empty_plot_style = frozendict(
+        xaxis={"visible": False},
+        yaxis={"visible": False},
+        paper_bgcolor="rgba(0,0,0,0)",
+        plot_bgcolor="rgba(0,0,0,0)",
+    )
 
-    colorscale_classic = [
+    colorscale_classic = (
         [0.00, "#4728fa"],  # blue
         [0.33, "#f9f273"],  # yellow
         [0.66, "#e5211b"],  # red
         [1.00, "#ffffff"],  # white
-    ]
+    )
 
     colorscale = "magma"
 
-    default_table_params = [
+    default_table_params = (
         {"col": "Material ID", "edit": False},
         {"col": "Formula", "edit": True},
         {"col": "Formation Energy (eV/atom)", "edit": True},
         {"col": "Energy Above Hull (eV/atom)", "edit": False},
         {"col": "Predicted Stable?", "edit": False},
-    ]
+    )
 
-    empty_row = {
-        "Material ID": None,
-        "Formula": "INSERT",
-        "Formation Energy (eV/atom)": "INSERT",
-        "Energy Above Hull (eV/atom)": None,
-        "Predicted Stable": None,
-    }
+    empty_row = frozendict(
+        {
+            "Material ID": None,
+            "Formula": "INSERT",
+            "Formation Energy (eV/atom)": "INSERT",
+            "Energy Above Hull (eV/atom)": None,
+            "Predicted Stable": None,
+        }
+    )
 
     # @staticmethod
     # def get_figure_with_shapes(
@@ -161,7 +165,7 @@ class PourbaixDiagramComponent(MPComponent):
     #
     #         if not heatmap_as_contour:
     #             # Plotly needs a list here for validation
-    #             hmap = go.Heatmap(
+    #             h_map = go.Heatmap(
     #                 x=list(ph_range),
     #                 y=list(v_range),
     #                 z=decomposition_e,
@@ -175,11 +179,11 @@ class PourbaixDiagramComponent(MPComponent):
     #                 zmin=0,
     #                 zmax=1,
     #             )
-    #             data.append(hmap)
+    #             data.append(h_map)
     #
     #         else:
     #
-    #             hmap = go.Contour(
+    #             h_map = go.Contour(
     #                 z=decomposition_e,
     #                 x=list(ph_range),
     #                 y=list(v_range),
@@ -192,10 +196,10 @@ class PourbaixDiagramComponent(MPComponent):
     #                 contours_coloring="heatmap",
     #                 text=hovertexts,
     #             )
-    #             data.insert(0, hmap)
+    #             data.insert(0, h_map)
     #
     #     shapes = []
-    #     xydata = []
+    #     xy_data = []
     #     labels = []
     #
     #     for entry, vertices in pourbaix_diagram._stable_domain_vertices.items():
@@ -203,14 +207,14 @@ class PourbaixDiagramComponent(MPComponent):
     #         clean_formula = PourbaixDiagramComponent.clean_formula(formula)
     #
     #         # Generate annotation
-    #         xydata.append(np.average(vertices, axis=0))
+    #         xy_data.append(np.average(vertices, axis=0))
     #         labels.append(clean_formula)
     #
     #         # Info on SVG paths: https://developer.mozilla.org/en-US/docs/Web/SVG/Tutorial/Paths
     #         # Move to first point
     #         path = "M {},{}".format(*vertices[0])
     #         # Draw lines to each other point
-    #         path += "".join(["L {},{}".format(*vertex) for vertex in vertices[1:]])
+    #         path += "".join("L {},{}".format(*vertex) for vertex in vertices[1:])
     #         # Close path
     #         path += "Z"
     #
@@ -239,7 +243,7 @@ class PourbaixDiagramComponent(MPComponent):
     #         )
     #         shapes.append(shape)
     #
-    #     layout = PourbaixDiagramComponent.default_plot_style
+    #     layout = {**PourbaixDiagramComponent.default_plot_style}
     #     layout.update({"shapes": shapes})
     #
     #     if show_labels:
@@ -261,11 +265,11 @@ class PourbaixDiagramComponent(MPComponent):
     #                     "y": y,
     #                     "yref": "y",
     #                 }
-    #                 for (x, y), label in zip(xydata, labels)
+    #                 for (x, y), label in zip(xy_data, labels)
     #             ]
     #             layout.update({"annotations": annotations})
     #         else:
-    #             x, y = zip(*xydata)
+    #             x, y = zip(*xy_data)
     #             data.append(
     #                 go.Scatter(x=x, y=y, text=labels, hoverinfo="text", mode="markers")
     #             )
@@ -291,7 +295,7 @@ class PourbaixDiagramComponent(MPComponent):
         data = []
 
         shapes = []
-        xydata = []
+        xy_data = []
         labels = []
         domain_heights = []
 
@@ -308,7 +312,7 @@ class PourbaixDiagramComponent(MPComponent):
 
             # Ensure label is within plot area
             # TODO: remove hard-coded value here and make sure it's set dynamically
-            xydata.append([centroid.x, centroid.y])
+            xy_data.append([centroid.x, centroid.y])
             labels.append(clean_formula)
             domain_heights.append(height)
 
@@ -355,7 +359,7 @@ class PourbaixDiagramComponent(MPComponent):
                     marker={"color": "Black"},
                     line={"color": "Black", "width": 0},
                     mode="lines",
-                    showlegend=True if legend_entry not in include_legend else False,
+                    showlegend=legend_entry not in include_legend,
                 )
             )
 
@@ -367,31 +371,28 @@ class PourbaixDiagramComponent(MPComponent):
             # Move to first point
             path = "M {},{}".format(*vertices[0])
             # Draw lines to each other point
-            path += "".join(["L {},{}".format(*vertex) for vertex in vertices[1:]])
+            path += "".join("L {},{}".format(*vertex) for vertex in vertices[1:])
             # Close path
             path += "Z"
 
             # stable entries are black with default color scheme,
             # so use white lines instead
-            if heatmap_entry:
-                line = {"color": "White", "width": 4}
-            else:
-                line = {"color": "Black", "width": 1}
+            line = (
+                {"color": "White", "width": 4}
+                if heatmap_entry
+                else {"color": "Black", "width": 1}
+            )
 
             shape = go.layout.Shape(
-                type="path",
-                path=path,
-                fillcolor="rgba(0,0,0,0)",
-                opacity=1,
-                line=line,
+                type="path", path=path, fillcolor="rgba(0,0,0,0)", opacity=1, line=line
             )
             shapes.append(shape)
 
-        layout = PourbaixDiagramComponent.default_plot_style
+        layout = {**PourbaixDiagramComponent.default_plot_style}
         layout.update({"shapes": shapes})
 
         if heatmap_entry is None:
-            x, y = zip(*xydata)
+            x, y = zip(*xy_data)
             data.append(
                 go.Scatter(
                     x=x, y=y, text=labels, hoverinfo="text", mode="text", name="Labels"
@@ -439,7 +440,7 @@ class PourbaixDiagramComponent(MPComponent):
                     "y": y,
                     "yref": "y",
                 }
-                for (x, y), label, height in zip(xydata, labels, domain_heights)
+                for (x, y), label, height in zip(xy_data, labels, domain_heights)
             ]
             layout.update({"annotations": annotations})
 
@@ -475,7 +476,7 @@ class PourbaixDiagramComponent(MPComponent):
                 Composition(heatmap_entry.composition).reduced_formula
             )
 
-            hmap = go.Contour(
+            h_map = go.Contour(
                 z=decomposition_e,
                 x=list(ph_range),
                 y=list(v_range),
@@ -494,7 +495,7 @@ class PourbaixDiagramComponent(MPComponent):
                 name=f"{heatmap_formula} ({heatmap_entry.entry_id}) Heatmap",
                 showlegend=True,
             )
-            data.append(hmap)
+            data.append(h_map)
 
         if show_water_lines:
             ph_range = [-2, 16]
@@ -526,9 +527,7 @@ class PourbaixDiagramComponent(MPComponent):
             # #
             # #   ))
 
-        figure = go.Figure(data=data, layout=layout)
-
-        return figure
+        return go.Figure(data=data, layout=layout)
 
     # TODO: format formula
     @staticmethod
@@ -537,14 +536,10 @@ class PourbaixDiagramComponent(MPComponent):
         clean_formula = re.sub(r"\[([0-9+-]+)\]", r"<sup>\1</sup>", formula)
 
         # Subscript coefficients
-        clean_formula = re.sub(
-            r"([A-Za-z\(\)])([\d\.]+)", r"\1<sub>\2</sub>", clean_formula
-        )
-        return clean_formula
+        return re.sub(r"([A-Za-z\(\)])([\d\.]+)", r"\1<sub>\2</sub>", clean_formula)
 
     @property
-    def _sub_layouts(self):
-
+    def _sub_layouts(self) -> dict[str, Component]:
         options = html.Div(
             [
                 self.get_bool_input(
@@ -554,7 +549,7 @@ class PourbaixDiagramComponent(MPComponent):
                     help_str="Whether to filter solid phases by stability on the compositional phase diagram. "
                     "The practical consequence of this is that highly oxidized or reduced phases that "
                     "might show up in experiments due to kinetic limitations on oxygen/hydrogen evolution "
-                    "won’t appear in the diagram, but they are not actually “stable” (and are frequently "
+                    "won't appear in the diagram, but they are not actually “stable” (and are frequently "
                     "overstabilized from DFT errors). Hence, including only the stable solid phases generally "
                     "leads to the most accurate Pourbaix diagrams.",
                 ),
@@ -583,7 +578,7 @@ class PourbaixDiagramComponent(MPComponent):
 
         graph = html.Div(
             dcc.Graph(
-                figure=go.Figure(layout=PourbaixDiagramComponent.empty_plot_style),
+                figure=go.Figure(layout={**PourbaixDiagramComponent.empty_plot_style}),
                 id=self.id("graph"),
                 responsive=True,
                 config={"displayModeBar": False, "displaylogo": False},
@@ -593,21 +588,17 @@ class PourbaixDiagramComponent(MPComponent):
 
         return {"graph": graph, "options": options}
 
-    def layout(self):
+    def layout(self) -> html.Div:
         return html.Div(
-            children=[
-                self._sub_layouts["options"],
-                self._sub_layouts["graph"],
-            ]
+            children=[self._sub_layouts["options"], self._sub_layouts["graph"]]
         )
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         @app.callback(
             Output(self.id("heatmap_choice_container"), "children"),
             Input(self.id(), "data"),
         )
         def update_heatmap_choices(entries):
-
             if not entries:
                 raise PreventUpdate
 
@@ -619,7 +610,7 @@ class PourbaixDiagramComponent(MPComponent):
                     mpid = entry["entry_id"]
                     options.append({"label": f"{formula} ({mpid})", "value": mpid})
 
-            heatmap_options = self.get_choice_input(
+            return self.get_choice_input(
                 "heatmap_choice",
                 state={},
                 label="Heatmap Entry",
@@ -628,16 +619,13 @@ class PourbaixDiagramComponent(MPComponent):
                 disabled=False,
             )
 
-            return heatmap_options
-
         @app.callback(
             Output(self.id("element_specific_controls"), "children"),
             Input(self.id(), "data"),
             Input(self.get_kwarg_id("heatmap_choice"), "value"),
-            [State(self.get_kwarg_id("show_heatmap"), "value")],
+            State(self.get_kwarg_id("show_heatmap"), "value"),
         )
         def update_element_specific_sliders(entries, heatmap_choice, show_heatmap):
-
             if not entries:
                 raise PreventUpdate
 
@@ -702,23 +690,20 @@ class PourbaixDiagramComponent(MPComponent):
                 comp_conc_controls.append(ctl.Label("Set Ion Concentration"))
             comp_conc_controls += conc_inputs
 
-            comp_conc_controls = html.Div(comp_conc_controls)
-
-            return comp_conc_controls
+            return html.Div(comp_conc_controls)
 
         @app.callback(
             Output(self.id("display-composition"), "children"),
             Input(self.get_all_kwargs_id(), "value"),
         )
         def update_displayed_composition(*args):
-
             kwargs = self.reconstruct_kwargs_from_state()
 
             comp_dict = {}
-            for k, v in kwargs.items():
-                if "comp" in k:  # keys are encoded like "comp-Ag"
-                    el = k.split("-")[1]
-                    comp_dict[el] = v
+            for key, val in kwargs.items():
+                if "comp" in key:  # keys are encoded like "comp-Ag"
+                    el = key.split("-")[1]
+                    comp_dict[el] = val
             comp_dict = comp_dict or None
 
             if not comp_dict:
@@ -742,13 +727,10 @@ class PourbaixDiagramComponent(MPComponent):
 
         @app.callback(
             Output(self.id("graph"), "figure"),
-            [
-                Input(self.id(), "data"),
-                Input(self.get_all_kwargs_id(), "value"),
-            ],
+            Input(self.id(), "data"),
+            Input(self.get_all_kwargs_id(), "value"),
         )
         def make_figure(pourbaix_entries, *args) -> go.Figure:
-
             if pourbaix_entries is None:
                 raise PreventUpdate
 
@@ -758,7 +740,6 @@ class PourbaixDiagramComponent(MPComponent):
 
             # Get heatmap id
             if kwargs["show_heatmap"] and kwargs.get("heatmap_choice"):
-
                 # get Entry object based on the heatmap_choice, which is entry_id string
                 heatmap_entry = next(
                     entry
@@ -779,19 +760,19 @@ class PourbaixDiagramComponent(MPComponent):
                 comp_dict = {}
                 # e.g. kwargs contains {"comp-Ag": 0.5, "comp-Fe": 0.5},
                 # essentially {slider_name: slider_value}
-                for k, v in kwargs.items():
-                    if "comp" in k:  # keys are encoded like "comp-Ag"
-                        el = k.split("-")[1]
-                        comp_dict[el] = v
+                for key, val in kwargs.items():
+                    if "comp" in key:  # keys are encoded like "comp-Ag"
+                        el = key.split("-")[1]
+                        comp_dict[el] = val
                 comp_dict = comp_dict or None
 
             conc_dict = {}
             # e.g. kwargs contains {"conc-Ag": 1e-6, "conc-Fe": 1e-4},
             # essentially {slider_name: slider_value}
-            for k, v in kwargs.items():
-                if "conc" in k:  # keys are encoded like "conc-Ag"
-                    el = k.split("-")[1]
-                    conc_dict[el] = v
+            for key, val in kwargs.items():
+                if "conc" in key:  # keys are encoded like "conc-Ag"
+                    el = key.split("-")[1]
+                    conc_dict[el] = val
             conc_dict = conc_dict or None
 
             pourbaix_diagram = get_pourbaix_diagram(
@@ -800,7 +781,7 @@ class PourbaixDiagramComponent(MPComponent):
                 conc_dict=conc_dict,
                 filter_solids=kwargs["filter_solids"],
             )
-            self.logger.debug(
+            self.logger.debug(  # noqa: PLE1205
                 "Generated pourbaix diagram",
                 len(pourbaix_entries),
                 heatmap_entry,
@@ -808,13 +789,11 @@ class PourbaixDiagramComponent(MPComponent):
                 comp_dict,
             )
 
-            fig = self.get_figure(
+            return self.get_figure(
                 pourbaix_diagram,
                 heatmap_entry=heatmap_entry,
             )
 
-            return fig
-
     # TODO
     # def graph_layout(self):
     #     return self._sub_layouts["graph"]
