@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from dash import html
 from dash.dependencies import Input, Output
 from robocrys import StructureCondenser, StructureDescriber
@@ -9,34 +11,28 @@ from crystal_toolkit.helpers.layouts import Loading, MessageBody, MessageContain
 
 class RobocrysComponent(PanelComponent):
     @property
-    def title(self):
+    def title(self) -> str:
         return "Description"
 
     @property
-    def description(self):
+    def description(self) -> str:
         return (
             "Your friendly robocrystallographer tries to describe a structure much "
             "like a human crystallographer would."
         )
 
     def contents_layout(self) -> html.Div:
-
         return Loading(id=self.id("robocrys"))
 
-    def generate_callbacks(self, app, cache):
-
+    def generate_callbacks(self, app, cache) -> None:
         super().generate_callbacks(app, cache)
 
-        @app.callback(
-            Output(self.id("robocrys"), "children"), [Input(self.id(), "data")]
-        )
+        @app.callback(Output(self.id("robocrys"), "children"), Input(self.id(), "data"))
         @cache.memoize()
         def run_robocrys_analysis(new_store_contents):
-
             struct = self.from_data(new_store_contents)
 
             try:
-
                 condenser = StructureCondenser()
                 describer = StructureDescriber(fmt="unicode")
 
@@ -45,19 +41,13 @@ class RobocrysComponent(PanelComponent):
                 description = describer.describe(condensed_structure)
 
             except Exception as exc:
-
                 description = str(exc)
 
+            repo_link = html.A(
+                f"🤖 robocrys v{robocrys_version}",
+                href="https://github.com/hackingmaterials/robocrystallographer",
+                style={"white-space": "nowrap"},
+            )
             return MessageContainer(
-                MessageBody(
-                    [
-                        f"{description} – ",
-                        html.A(
-                            f"🤖 robocrys v{robocrys_version}",
-                            href="https://github.com/hackingmaterials/robocrystallographer",
-                            style={"white-space": "nowrap"},
-                        ),
-                    ]
-                ),
-                kind="dark",
+                MessageBody([f"{description} - ", repo_link]), kind="dark"
             )
