@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 import os
 from random import choice
 
 import numpy as np
 from dash import dcc, html
-from dash.dependencies import Input, Output, State
+from dash.dependencies import Component, Input, Output, State
 from dash.exceptions import PreventUpdate
 from monty.serialization import loadfn
 from mp_api.client import MPRester, MPRestError
@@ -22,18 +24,14 @@ from crystal_toolkit.helpers.layouts import (
 
 
 class SearchComponent(MPComponent):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.create_store("results")
 
     def _get_mpid_cache(self):
-
         path = os.path.join(os.path.dirname(module_path), "mpid_cache.json")
 
-        if os.path.isfile(path):
-            mpid_cache = loadfn(path)
-        else:
-            mpid_cache = []
+        mpid_cache = loadfn(path) if os.path.isfile(path) else []
         # else:
         #     try:
         #         with MPRester() as mpr:
@@ -55,7 +53,6 @@ class SearchComponent(MPComponent):
         self.mpid_cache = mpid_cache
 
     def _make_search_box(self, search_term=None):
-
         search_field = dcc.Input(
             id=self.id("input"),
             className="input",
@@ -79,8 +76,7 @@ class SearchComponent(MPComponent):
         )
 
     @property
-    def _sub_layouts(self):
-
+    def _sub_layouts(self) -> dict[str, Component]:
         search = html.Div(self._make_search_box(), id=self.id("search_container"))
 
         random_link = html.A(
@@ -102,36 +98,30 @@ class SearchComponent(MPComponent):
 
         return {"search": search}
 
-    def layout(self):
+    def layout(self) -> html.Div:
+        """Get the component layout."""
         return html.Div([self._sub_layouts["search"]])
 
-    def generate_callbacks(self, app, cache):
-
+    def generate_callbacks(self, app, cache) -> None:
         self._get_mpid_cache()
 
         @cache.memoize(timeout=0)
         def get_human_readable_results_from_search_term(search_term):
-
             # common confusables
             if search_term.isnumeric() and str(int(search_term)) == search_term:
                 search_term = f"mp-{search_term}"
             if search_term.startswith("mp") and "-" not in search_term:
                 search_term = f"mp-{search_term.split('mp')[1]}"
 
-            if search_term.startswith("mp-") or search_term.startswith("mvc-"):
+            if search_term.startswith(("mp-", "mvc-")):
                 # no need to actually search, support multiple mp-ids (space separated)
                 return {mpid: mpid for mpid in search_term.split(" ")}
 
+            fields = ["material_id", "formula_pretty", "energy_above_hull", "symmetry"]
             with MPRester() as mpr:
                 try:
                     entries = mpr.summary.search_summary_docs(
-                        formula=search_term,
-                        fields=[
-                            "material_id",
-                            "formula_pretty",
-                            "energy_above_hull",
-                            "symmetry",
-                        ],
+                        formula=search_term, fields=fields
                     )
                 except MPRestError:
                     entries = []
@@ -153,7 +143,7 @@ class SearchComponent(MPComponent):
                     e_hull_str = np.format_float_scientific(e_hull, precision=2)
                     human_readable_hull_labels.append(f"+{e_hull_str} eV/atom")
 
-            human_readable_results = {
+            return {
                 entry.material_id: f"{unicodeify(entry.formula_pretty)} "
                 f"({unicodeify_spacegroup(entry.symmetry.symbol)}) "
                 f"{human_readable_hull_label}"
@@ -162,15 +152,13 @@ class SearchComponent(MPComponent):
                 )
             }
 
-            return human_readable_results
-
         @app.callback(
             Output(self.id("results"), "data"),
-            [Input(self.id("input"), "n_submit"), Input(self.id("button"), "n_clicks")],
-            [State(self.id("input"), "value")],
+            Input(self.id("input"), "n_submit"),
+            Input(self.id("button"), "n_clicks"),
+            State(self.id("input"), "value"),
         )
         def update_results(n_submit, n_clicks, search_term):
-
             if not search_term:
                 raise PreventUpdate
 
@@ -183,7 +171,7 @@ class SearchComponent(MPComponent):
             return results
 
         @app.callback(
-            Output(self.id("dropdown"), "options"), [Input(self.id("results"), "data")]
+            Output(self.id("dropdown"), "options"), Input(self.id("results"), "data")
         )
         def update_dropdown_options(results):
             if not results or "error" in results:
@@ -191,7 +179,7 @@ class SearchComponent(MPComponent):
             return [{"value": mpid, "label": label} for mpid, label in results.items()]
 
         @app.callback(
-            Output(self.id("dropdown"), "value"), [Input(self.id("results"), "data")]
+            Output(self.id("dropdown"), "value"), Input(self.id("results"), "data")
         )
         def update_dropdown_value(results):
             if not results or "error" in results:
@@ -200,31 +188,29 @@ class SearchComponent(MPComponent):
 
         @app.callback(
             Output(self.id("dropdown-container"), "style"),
-            [Input(self.id("results"), "data")],
+            Input(self.id("results"), "data"),
         )
         def hide_show_dropdown(results):
             if not results or len(results) <= 1:
                 return {"display": "none"}
-            else:
-                return {}
+            return {}
 
         @app.callback(
-            Output(self.id("warning"), "children"), [Input(self.id("results"), "data")]
+            Output(self.id("warning"), "children"), Input(self.id("results"), "data")
         )
         def show_warning(results):
             if results and "error" in results:
                 return MessageContainer(MessageBody(results["error"]))
-            else:
-                return html.Div()
+            return html.Div()
 
         @app.callback(
             Output(self.id("search_container"), "children"),
-            [Input(self.id("random"), "n_clicks")],
+            Input(self.id("random"), "n_clicks"),
         )
-        def update_displayed_mpid(random_n_clicks):
+        def update_displayed_mpid(n_clicks):
             # TODO: this is a really awkward solution to a complex callback chain, improve in future?
             return self._make_search_box(search_term=choice(self.mpid_cache))
 
-        @app.callback(Output(self.id(), "data"), [Input(self.id("dropdown"), "value")])
+        @app.callback(Output(self.id(), "data"), Input(self.id("dropdown"), "value"))
         def update_store_from_value(mpid):
             return mpid
