@@ -3,23 +3,22 @@ from __future__ import annotations
 import re
 import warnings
 from base64 import b64encode
-from collections import OrderedDict
 from itertools import chain, combinations_with_replacement
 from pathlib import Path
 from tempfile import TemporaryDirectory
-from typing import Literal
+from typing import Any, Literal
 
 import numpy as np
 from dash import dash_table as dt
-from dash.dependencies import Input, Output, State
+from dash.dependencies import Component, Input, Output, State
 from dash.exceptions import PreventUpdate
 from dash_mp_components import CrystalToolkitScene
 from emmet.core.settings import EmmetSettings
+from frozendict import frozendict
 from pymatgen.analysis.graphs import MoleculeGraph, StructureGraph
 from pymatgen.analysis.local_env import NearNeighbors
-from pymatgen.core.composition import Composition
+from pymatgen.core import Composition, Molecule, Species, Structure
 from pymatgen.core.periodic_table import DummySpecie
-from pymatgen.core.structure import Molecule, Structure
 from pymatgen.io.vasp.sets import MPRelaxSet
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
@@ -55,26 +54,25 @@ class StructureMoleculeComponent(MPComponent):
     objects.
     """
 
-    available_bonding_strategies = {
-        subclass.__name__: subclass for subclass in NearNeighbors.__subclasses__()
-    }
+    available_bonding_strategies = frozendict(
+        {subcls.__name__: subcls for subcls in NearNeighbors.__subclasses__()}
+    )
 
-    default_scene_settings = {
-        "extractAxis": True,
-        # For visual diff testing, we change the renderer
-        # to SVG since this WebGL support is more difficult
-        # in headless browsers / CI.
-        "renderer": "svg" if SETTINGS.TEST_MODE else "webgl",
-        "secondaryObjectView": False,
-    }
+    default_scene_settings = frozendict(
+        extractAxis=True,
+        # For visual diff testing, we change the renderer to SVG since this WebGL
+        # support is more difficult in headless browsers / CI.
+        renderer="svg" if SETTINGS.TEST_MODE else "webgl",
+        secondaryObjectView=False,
+    )
 
     # what to show for the title_layout if structure/molecule not loaded
     default_title = "Crystal Toolkit"
 
     # human-readable label to file extension
     # downloading Molecules has not yet been added
-    download_options = {
-        "Structure": {
+    download_options = frozendict(
+        Structure={
             "CIF (Symmetrized)": {"fmt": "cif", "symprec": EmmetSettings().SYMPREC},
             "CIF": {"fmt": "cif"},
             "POSCAR": {"fmt": "poscar"},
@@ -82,13 +80,14 @@ class StructureMoleculeComponent(MPComponent):
             "Prismatic": {"fmt": "prismatic"},
             "VASP Input Set (MPRelaxSet)": {},  # special
         }
-    }
+    )
 
     def __init__(
         self,
-        struct_or_mol: None
-        | (Structure | StructureGraph | Molecule | MoleculeGraph) = None,
-        id: str = None,
+        struct_or_mol: (
+            None | Structure | StructureGraph | Molecule | MoleculeGraph
+        ) = None,
+        id: str | None = None,
         className: str = "box",
         scene_additions: Scene | None = None,
         bonding_strategy: str = DEFAULTS["bonding_strategy"],
@@ -113,7 +112,7 @@ class StructureMoleculeComponent(MPComponent):
         show_export_button: bool = DEFAULTS["show_export_button"],
         show_position_button: bool = DEFAULTS["show_position_button"],
         **kwargs,
-    ):
+    ) -> None:
         """Create a StructureMoleculeComponent from a structure or molecule.
 
         Args:
@@ -158,7 +157,7 @@ class StructureMoleculeComponent(MPComponent):
         self.show_export_button = show_export_button
         self.show_position_button = show_position_button
 
-        self.initial_scene_settings = self.default_scene_settings.copy()
+        self.initial_scene_settings = {**self.default_scene_settings}
         if scene_settings:
             self.initial_scene_settings.update(scene_settings)
 
@@ -235,15 +234,24 @@ class StructureMoleculeComponent(MPComponent):
         self._initial_data["scene"] = scene
 
         # hide axes inset for molecules
-        if isinstance(struct_or_mol, Molecule) or isinstance(
-            struct_or_mol, MoleculeGraph
-        ):
+        if isinstance(struct_or_mol, (Molecule, MoleculeGraph)):
             self.scene_kwargs = {"axisView": "HIDDEN"}
         else:
             self.scene_kwargs = {}
 
-    def generate_callbacks(self, app, cache):
+    def __str__(self) -> str:
+        return repr(self)
 
+    def __repr__(self) -> str:
+        # TODO due to the current increment ID counter until unique, incl. component ID in the repr breaks unit tests
+        # consider adding ID to repr once ID creation is less brittle
+        # id = self._id
+        struct_or_mol = self._initial_data["default"]
+        formula = getattr(struct_or_mol, "formula", None)
+        atoms = getattr(struct_or_mol, "num_sites", None)
+        return f"StructureMoleculeComponent({formula=}, {atoms=})"
+
+    def generate_callbacks(self, app, cache) -> None:
         # a lot of the verbosity in this callback is to support custom bonding
         # this is not the format CutOffDictNN expects (since that is not JSON
         # serializable), so we store as a list of tuples instead
@@ -269,11 +277,9 @@ class StructureMoleculeComponent(MPComponent):
             }
             """,
             Output(self.id("graph_generation_options"), "data"),
-            [
-                Input(self.id("bonding_algorithm"), "value"),
-                Input(self.id("bonding_algorithm_custom_cutoffs"), "data"),
-                Input(self.id("unit-cell-choice"), "value"),
-            ],
+            Input(self.id("bonding_algorithm"), "value"),
+            Input(self.id("bonding_algorithm_custom_cutoffs"), "data"),
+            Input(self.id("unit-cell-choice"), "value"),
         )
 
         app.clientside_callback(
@@ -287,8 +293,8 @@ class StructureMoleculeComponent(MPComponent):
             }
             """,
             Output(self.id("scene"), "toggleVisibility"),
-            [Input(self.id("hide-show"), "value")],
-            [State(self.id("hide-show"), "options")],
+            Input(self.id("hide-show"), "value"),
+            State(self.id("hide-show"), "options"),
         )
 
         app.clientside_callback(
@@ -308,25 +314,20 @@ class StructureMoleculeComponent(MPComponent):
             }
             """,
             Output(self.id("display_options"), "data"),
-            [
-                Input(self.id("color-scheme"), "value"),
-                Input(self.id("radius_strategy"), "value"),
-                Input(self.id("draw_options"), "value"),
-            ],
-            [State(self.id("display_options"), "data")],
+            Input(self.id("color-scheme"), "value"),
+            Input(self.id("radius_strategy"), "value"),
+            Input(self.id("draw_options"), "value"),
+            State(self.id("display_options"), "data"),
         )
 
         @app.callback(
             Output(self.id("graph"), "data"),
-            [
-                Input(self.id("graph_generation_options"), "data"),
-                Input(self.id(), "data"),
-            ],
-            [State(self.id("graph"), "data")],
+            Input(self.id("graph_generation_options"), "data"),
+            Input(self.id(), "data"),
+            State(self.id("graph"), "data"),
         )
         @cache.memoize()
         def update_graph(graph_generation_options, struct_or_mol, current_graph):
-
             if not struct_or_mol:
                 raise PreventUpdate
 
@@ -347,22 +348,31 @@ class StructureMoleculeComponent(MPComponent):
                 bonding_strategy_kwargs=bonding_strategy_kwargs,
             )
 
-            if (
-                current_graph
-                and graph.structure == current_graph.structure
-                and graph == current_graph
-            ):
-                raise PreventUpdate
+            # don't update if the graph did not change.
+            if current_graph:
+                graph_struct_or_mol = (
+                    graph.structure
+                    if isinstance(graph, StructureGraph)
+                    else graph.molecule
+                )
+                current_graph_struct_or_mol = (
+                    current_graph.structure
+                    if isinstance(current_graph, StructureGraph)
+                    else current_graph.molecule
+                )
+                if (
+                    graph_struct_or_mol == current_graph_struct_or_mol
+                    and graph == current_graph
+                ):
+                    raise PreventUpdate
 
             return graph
 
         @app.callback(
             Output(self.id("scene"), "data"),
-            [
-                Input(self.id("graph"), "data"),
-                Input(self.id("display_options"), "data"),
-                Input(self.id("scene_additions"), "data"),
-            ],
+            Input(self.id("graph"), "data"),
+            Input(self.id("display_options"), "data"),
+            Input(self.id("scene_additions"), "data"),
         )
         @cache.memoize()
         def update_scene(graph, display_options, scene_additions):
@@ -377,11 +387,9 @@ class StructureMoleculeComponent(MPComponent):
 
         @app.callback(
             Output(self.id("legend_data"), "data"),
-            [
-                Input(self.id("graph"), "data"),
-                Input(self.id("display_options"), "data"),
-                Input(self.id("scene_additions"), "data"),
-            ],
+            Input(self.id("graph"), "data"),
+            Input(self.id("display_options"), "data"),
+            Input(self.id("scene_additions"), "data"),
         )
         @cache.memoize()
         def update_legend_and_colors(graph, display_options, scene_additions):
@@ -396,10 +404,9 @@ class StructureMoleculeComponent(MPComponent):
 
         @app.callback(
             Output(self.id("color-scheme"), "options"),
-            [Input(self.id("legend_data"), "data")],
+            Input(self.id("legend_data"), "data"),
         )
         def update_color_options(legend_data):
-
             # TODO: make client-side
             color_options = [
                 {"label": "Jmol", "value": "Jmol"},
@@ -420,29 +427,23 @@ class StructureMoleculeComponent(MPComponent):
         # app.clientside_callback(
         #     """
         #     function (legendData) {
-        #
-        #         var colorOptions = [
+        #         const colorOptions = [
         #             {label: "Jmol", value: "Jmol"},
         #             {label: "VESTA", value: "VESTA"},
         #             {label: "Accessible", value: "accessible"},
         #         ]
-        #
-        #
-        #
         #         return colorOptions
         #     }
         #     """,
         #     Output(self.id("color-scheme"), "options"),
-        #     [Input(self.id("legend_data"), "data")]
+        #     Input(self.id("legend_data"), "data"),
         # )
 
         @app.callback(
             Output(self.id("download-image"), "data"),
             Input(self.id("scene"), "imageDataTimestamp"),
-            [
-                State(self.id("scene"), "imageData"),
-                State(self.id(), "data"),
-            ],
+            State(self.id("scene"), "imageData"),
+            State(self.id(), "data"),
         )
         def download_image(image_data_timestamp, image_data, data):
             if not image_data_timestamp:
@@ -455,11 +456,12 @@ class StructureMoleculeComponent(MPComponent):
                 formula = struct_or_mol.molecule.composition.reduced_Formula
             else:
                 formula = struct_or_mol.composition.reduced_formula
-            if hasattr(struct_or_mol, "get_space_group_info"):
-                spgrp = struct_or_mol.get_space_group_info()[0]
-            else:
-                spgrp = ""
-            request_filename = f"{formula}-{spgrp}-crystal-toolkit.png"
+            spg_symbol = (
+                struct_or_mol.get_space_group_info()[0]
+                if hasattr(struct_or_mol, "get_space_group_info")
+                else ""
+            )
+            request_filename = f"{formula}-{spg_symbol}-crystal-toolkit.png"
 
             return {
                 "content": image_data[len("data:image/png;base64,") :],
@@ -471,10 +473,8 @@ class StructureMoleculeComponent(MPComponent):
         @app.callback(
             Output(self.id("download-structure"), "data"),
             Input(self.id("scene"), "fileTimestamp"),
-            [
-                State(self.id("scene"), "fileType"),
-                State(self.id(), "data"),
-            ],
+            State(self.id("scene"), "fileType"),
+            State(self.id(), "data"),
         )
         def download_structure(file_timestamp, download_option, data):
             if not file_timestamp:
@@ -487,7 +487,6 @@ class StructureMoleculeComponent(MPComponent):
             file_prefix = structure.composition.reduced_formula
 
             if "VASP" not in download_option:
-
                 extension = self.download_options["Structure"][download_option]["fmt"]
                 options = self.download_options["Structure"][download_option]
 
@@ -507,7 +506,6 @@ class StructureMoleculeComponent(MPComponent):
                 }
 
             else:
-
                 if "Relax" in download_option:
                     vis = MPRelaxSet(structure)
                     expected_filename = "MPRelaxSet.zip"
@@ -530,11 +528,10 @@ class StructureMoleculeComponent(MPComponent):
 
         @app.callback(
             Output(self.id("title_container"), "children"),
-            [Input(self.id("legend_data"), "data")],
+            Input(self.id("legend_data"), "data"),
         )
         @cache.memoize()
         def update_title(legend):
-
             if not legend:
                 raise PreventUpdate
 
@@ -544,11 +541,10 @@ class StructureMoleculeComponent(MPComponent):
 
         @app.callback(
             Output(self.id("legend_container"), "children"),
-            [Input(self.id("legend_data"), "data")],
+            Input(self.id("legend_data"), "data"),
         )
         @cache.memoize()
         def update_legend(legend):
-
             if not legend:
                 raise PreventUpdate
 
@@ -557,19 +553,14 @@ class StructureMoleculeComponent(MPComponent):
             return self._make_legend(legend)
 
         @app.callback(
-            [
-                Output(self.id("bonding_algorithm_custom_cutoffs"), "data"),
-                Output(self.id("bonding_algorithm_custom_cutoffs_container"), "style"),
-            ],
-            [Input(self.id("bonding_algorithm"), "value")],
-            [
-                State(self.id("graph"), "data"),
-                State(self.id("bonding_algorithm_custom_cutoffs_container"), "style"),
-            ],
+            Output(self.id("bonding_algorithm_custom_cutoffs"), "data"),
+            Output(self.id("bonding_algorithm_custom_cutoffs_container"), "style"),
+            Input(self.id("bonding_algorithm"), "value"),
+            State(self.id("graph"), "data"),
+            State(self.id("bonding_algorithm_custom_cutoffs_container"), "style"),
         )
         @cache.memoize()
         def update_custom_bond_options(bonding_algorithm, graph, current_style):
-
             if not graph:
                 raise PreventUpdate
 
@@ -582,33 +573,27 @@ class StructureMoleculeComponent(MPComponent):
                     raise PreventUpdate
 
             graph = self.from_data(graph)
-            rows = self._make_bonding_algorithm_custom_cuffoff_data(graph)
+            rows = self._make_bonding_algorithm_custom_cutoff_data(graph)
 
             return rows, style
 
     def _make_legend(self, legend):
-
         if not legend:
             return html.Div(id=self.id("legend"))
 
         def get_font_color(hex_code):
             # ensures contrasting font color for background color
             c = tuple(int(hex_code[1:][i : i + 2], 16) for i in (0, 2, 4))
-            if 1 - (c[0] * 0.299 + c[1] * 0.587 + c[2] * 0.114) / 255 < 0.5:
-                font_color = "#000000"
-            else:
-                font_color = "#ffffff"
-            return font_color
+            return (
+                "black"
+                if 1 - (c[0] * 0.299 + c[1] * 0.587 + c[2] * 0.114) / 255 < 0.5
+                else "white"
+            )
 
-        try:
-            formula = Composition.from_dict(legend["composition"]).reduced_formula
-        except Exception:
-            # TODO: fix legend for DummySpecies compositions
-            formula = "Unknown"
-
-        legend_colors = OrderedDict(
-            sorted(list(legend["colors"].items()), key=lambda x: formula.find(x[1]))
-        )
+        legend_colors = {
+            key: self._legend.get_color(Species(key))
+            for key, val in legend["composition"].items()
+        }
 
         legend_elements = [
             html.Span(
@@ -618,7 +603,7 @@ class StructureMoleculeComponent(MPComponent):
                 className="button is-static is-rounded",
                 style={"backgroundColor": color},
             )
-            for color, name in legend_colors.items()
+            for name, color in legend_colors.items()
         ]
 
         return html.Div(
@@ -629,13 +614,11 @@ class StructureMoleculeComponent(MPComponent):
         )
 
     def _make_title(self, legend):
-
         if not legend or (not legend.get("composition", None)):
             return H2(self.default_title, id=self.id("title"))
 
         composition = legend["composition"]
         if isinstance(composition, dict):
-
             try:
                 composition = Composition.from_dict(composition)
 
@@ -664,7 +647,7 @@ class StructureMoleculeComponent(MPComponent):
         )
 
     @staticmethod
-    def _make_bonding_algorithm_custom_cuffoff_data(graph):
+    def _make_bonding_algorithm_custom_cutoff_data(graph) -> list[dict[str, Any]]:
         if not graph:
             return [{"A": None, "B": None, "A—B": None}]
         struct_or_mol = StructureMoleculeComponent._get_struct_or_mol(graph)
@@ -675,15 +658,13 @@ class StructureMoleculeComponent(MPComponent):
                 chain.from_iterable([list(c) for c in struct_or_mol.species_and_occu]),
             )
         )
-        rows = [
+        return [  # rows
             {"A": combination[0], "B": combination[1], "A—B": 0}
             for combination in combinations_with_replacement(species, 2)
         ]
-        return rows
 
     @property
-    def _sub_layouts(self):
-
+    def _sub_layouts(self) -> dict[str, Component]:
         title_layout = html.Div(
             self._make_title(self._initial_data["legend_data"]),
             id=self.id("title_container"),
@@ -700,7 +681,7 @@ class StructureMoleculeComponent(MPComponent):
         }
 
         bonding_algorithm = dcc.Dropdown(
-            options=[{"label": k, "value": v} for k, v in nn_mapping.items()],
+            options=[{"label": key, "value": val} for key, val in nn_mapping.items()],
             value=self.initial_data["graph_generation_options"]["bonding_strategy"],
             clearable=False,
             id=self.id("bonding_algorithm"),
@@ -718,7 +699,7 @@ class StructureMoleculeComponent(MPComponent):
                         {"name": "A—B /Å", "id": "A—B"},
                     ],
                     editable=True,
-                    data=self._make_bonding_algorithm_custom_cuffoff_data(
+                    data=self._make_bonding_algorithm_custom_cutoff_data(
                         self.initial_data.get("default")
                     ),
                     id=self.id("bonding_algorithm_custom_cutoffs"),
@@ -732,7 +713,7 @@ class StructureMoleculeComponent(MPComponent):
         if self.show_settings:
             options_layout = Field(
                 [
-                    #  TODO: hide if molecule
+                    # TODO: hide if molecule
                     html.Label("Change unit cell:", className="mpc-label"),
                     html.Div(
                         dcc.Dropdown(
@@ -923,21 +904,26 @@ class StructureMoleculeComponent(MPComponent):
             "input", "primitive", "conventional", "reduced_niggli", "reduced_lll"
         ] = "input",
     ):
-        if isinstance(struct_or_mol, Structure):
-            if unit_cell_choice != "input":
-                if unit_cell_choice == "primitive":
-                    struct_or_mol = struct_or_mol.get_primitive_structure()
-                elif unit_cell_choice == "conventional":
-                    sga = SpacegroupAnalyzer(struct_or_mol)
-                    struct_or_mol = sga.get_conventional_standard_structure()
-                elif unit_cell_choice == "reduced_niggli":
-                    struct_or_mol = struct_or_mol.get_reduced_structure(
-                        reduction_algo="niggli"
-                    )
-                elif unit_cell_choice == "reduced_lll":
-                    struct_or_mol = struct_or_mol.get_reduced_structure(
-                        reduction_algo="LLL"
-                    )
+        if isinstance(struct_or_mol, StructureGraph) and unit_cell_choice != "input":
+            # if a user is visualizing a StructureGraph, but wants to change the unit cell
+            # convention, currently this means we have to convert the StructureGraph back
+            # to a Structure; this will remove all bonding information and mean bonding
+            # will also have to be re-calculated
+            struct_or_mol = struct_or_mol.structure
+        if isinstance(struct_or_mol, Structure) and unit_cell_choice != "input":
+            if unit_cell_choice == "primitive":
+                struct_or_mol = struct_or_mol.get_primitive_structure()
+            elif unit_cell_choice == "conventional":
+                sga = SpacegroupAnalyzer(struct_or_mol)
+                struct_or_mol = sga.get_conventional_standard_structure()
+            elif unit_cell_choice == "reduced_niggli":
+                struct_or_mol = struct_or_mol.get_reduced_structure(
+                    reduction_algo="niggli"
+                )
+            elif unit_cell_choice == "reduced_lll":
+                struct_or_mol = struct_or_mol.get_reduced_structure(
+                    reduction_algo="LLL"
+                )
         return struct_or_mol
 
     @staticmethod
@@ -946,9 +932,7 @@ class StructureMoleculeComponent(MPComponent):
         bonding_strategy: str = DEFAULTS["bonding_strategy"],
         bonding_strategy_kwargs: dict | None = None,
     ) -> StructureGraph | MoleculeGraph:
-
         if isinstance(input, Structure):
-
             # ensure fractional coordinates are normalized to be in [0,1)
             # (this is actually not guaranteed by Structure)
             try:
@@ -967,7 +951,7 @@ class StructureMoleculeComponent(MPComponent):
         # we assume most uses of this class will give a structure as an input argument,
         # meaning we have to calculate the graph for bonding information, however if
         # the graph is already known and supplied, we will use that
-        if isinstance(input, StructureGraph) or isinstance(input, MoleculeGraph):
+        if isinstance(input, (StructureGraph, MoleculeGraph)):
             graph = input
         else:
             if (
@@ -983,13 +967,15 @@ class StructureMoleculeComponent(MPComponent):
                 )
             else:
                 bonding_strategy_kwargs = bonding_strategy_kwargs or {}
-                if bonding_strategy == "CutOffDictNN":
-                    if "cut_off_dict" in bonding_strategy_kwargs:
-                        # TODO: remove this hack by making args properly JSON serializable
-                        bonding_strategy_kwargs["cut_off_dict"] = {
-                            (x[0], x[1]): x[2]
-                            for x in bonding_strategy_kwargs["cut_off_dict"]
-                        }
+                if (
+                    bonding_strategy == "CutOffDictNN"
+                    and "cut_off_dict" in bonding_strategy_kwargs
+                ):
+                    # TODO: remove this hack by making args properly JSON serializable
+                    bonding_strategy_kwargs["cut_off_dict"] = {
+                        (x[0], x[1]): x[2]
+                        for x in bonding_strategy_kwargs["cut_off_dict"]
+                    }
                 bonding_strategy = (
                     StructureMoleculeComponent.available_bonding_strategies[
                         bonding_strategy
@@ -1021,18 +1007,19 @@ class StructureMoleculeComponent(MPComponent):
     ) -> Structure | Molecule:
         if isinstance(graph, StructureGraph):
             return graph.structure
-        elif isinstance(graph, MoleculeGraph):
+        if isinstance(graph, MoleculeGraph):
             return graph.molecule
-        elif isinstance(graph, Structure) or isinstance(graph, Molecule):
+        if isinstance(graph, (Structure, Molecule)):
             return graph
-        else:
-            raise ValueError
+        raise ValueError(
+            f"Invalid input type {graph}, expected one of Structure, Molecule, StructureGraph or MoleculeGraph"
+        )
 
-    @staticmethod
     def get_scene_and_legend(
+        self,
         graph: StructureGraph | MoleculeGraph | None,
-        color_scheme=DEFAULTS["color_scheme"],
-        color_scale=None,
+        color_scheme: str = DEFAULTS["color_scheme"],  # type: ignore[assignment]
+        color_scale: tuple[float, float] | None = None,
         radius_strategy=DEFAULTS["radius_strategy"],
         draw_image_atoms=DEFAULTS["draw_image_atoms"],
         bonded_sites_outside_unit_cell=DEFAULTS["bonded_sites_outside_unit_cell"],
@@ -1042,7 +1029,27 @@ class StructureMoleculeComponent(MPComponent):
         show_compass=DEFAULTS["show_compass"],
         group_by_site_property=None,
     ) -> tuple[Scene, dict[str, str]]:
+        """Get the scene and legend for a given graph.
 
+        Args:
+            graph (StructureGraph | MoleculeGraph | None): The graph to get the scene and legend for.
+            color_scheme (str, optional): Color scheme for the graph. Defaults to "VESTA".
+            color_scale (tuple[float, float], optional): A range of values to map to the
+                color scale. Defaults to None.
+            radius_strategy (str, optional): Strategy for determining atomic radii. Defaults to "uniform".
+            draw_image_atoms (bool, optional): Whether to draw atoms in image cells. Defaults to True.
+            bonded_sites_outside_unit_cell (bool, optional): Whether to draw bonded sites outside
+                the unit cell. Defaults to False.
+            hide_incomplete_bonds (bool, optional): Whether to hide incomplete bonds. Defaults to True.
+            explicitly_calculate_polyhedra_hull (bool, optional): Whether to explicitly
+                calculate the convex hull of polyhedra. Defaults to False.
+            scene_additions (dict, optional): Additional contents to include in the scene. Defaults to None.
+            show_compass (bool, optional): Whether to show a compass in the scene. Defaults to True.
+            group_by_site_property (str, optional): Property by which to group sites. Defaults to None.
+
+        Returns:
+            tuple[Scene, dict[str, str]]: A tuple containing the scene and legend for the given graph.
+        """
         scene = Scene(name="StructureMoleculeComponentScene")
 
         if graph is None:
@@ -1057,6 +1064,7 @@ class StructureMoleculeComponent(MPComponent):
             radius_scheme=radius_strategy,
             cmap_range=color_scale,
         )
+        self._legend = legend
 
         if isinstance(graph, StructureGraph):
             scene = graph.get_scene(
@@ -1086,7 +1094,5 @@ class StructureMoleculeComponent(MPComponent):
         return scene_json, legend.get_legend()
 
     def title_layout(self):
-        """
-        :return: A layout including the composition of the structure/molecule as a title.
-        """
+        """A layout including the composition of the structure/molecule as a title."""
         return self._sub_layouts["title"]
