@@ -1,10 +1,13 @@
+from __future__ import annotations
+
+import os
 from urllib import parse
 
 import requests
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 from mp_api.client import MPRester
-from pymatgen.core.structure import Structure
+from pymatgen.core import Structure
 from pymatgen.util.provenance import StructureNL
 
 from crystal_toolkit import __version__ as ct_version
@@ -16,11 +19,10 @@ from crystal_toolkit.helpers.layouts import (
     MessageHeader,
     dcc,
     html,
-    os,
 )
 
-# ask Donny Winston
-MP_CLIENT_KEY = os.environ.get("MP_CLIENT_KEY")
+# ask Patrick phuck@lbl.gov
+MP_CLIENT_KEY = os.getenv("MP_CLIENT_KEY")
 
 
 class SubmitSNLPanel(PanelComponent):
@@ -30,16 +32,16 @@ class SubmitSNLPanel(PanelComponent):
     extracted, and also requires a "SearchComponent_search_container" component.
     """
 
-    def __init__(self, *args, url_id=None, **kwargs):
+    def __init__(self, *args, url_id: str | None = None, **kwargs) -> None:
         self.url_id = url_id
         super().__init__(*args, **kwargs)
 
     @property
-    def title(self):
+    def title(self) -> str:
         return "Submit to Materials Project"
 
     @property
-    def description(self):
+    def description(self) -> str:
         return (
             "Help us complete our database by submitting your structure to "
             "MPComplete where we will add your structure to our calculation queue."
@@ -61,8 +63,7 @@ class SubmitSNLPanel(PanelComponent):
             ]
         )
 
-    def generate_callbacks(self, app, cache):
-
+    def generate_callbacks(self, app, cache) -> None:
         super().generate_callbacks(app, cache)
 
         def parse_token(url):
@@ -70,47 +71,36 @@ class SubmitSNLPanel(PanelComponent):
                 return None
             if url.startswith("?"):
                 url = url[1:]
-            token = dict(parse.parse_qsl(url)).get("token")
-            return token
+            return dict(parse.parse_qsl(url)).get("token")
 
         @cache.memoize(timeout=60 * 60 * 24)
         def get_token_response(token):
-
             url = "https://materialsproject.org/rest/v2/snl/get_user_info"
             payload = {"token": token, "client_key": MP_CLIENT_KEY}
 
-            contents = requests.post(url, data=payload).json()["response"]
-
-            return contents
+            return requests.post(url, data=payload).json()["response"]
 
         @app.callback(
-            [
-                Output(self.id("panel"), "style"),
-                # for MP Crystal Toolkit app only, this is brittle(!)
-                Output("SearchComponent_search_container", "style"),
-            ],
-            [Input("url", "search")],
+            Output(self.id("panel"), "style"),
+            # for MP Crystal Toolkit app only, this is brittle(!)
+            Output("SearchComponent_search_container", "style"),
+            Input("url", "search"),
         )
         def hide_panel_if_no_token(url):
-
             token = parse_token(url)
 
             if not token:
                 return {"display": "none"}, {}
-            else:
-                return {}, {}  # {"display": "none"}
+            return {}, {}  # {"display": "none"}
 
         @app.callback(
             Output(self.id("info"), "children"),
-            [
-                Input(self.id(), "data"),
-                Input(self.id("comments"), "value"),
-                Input(self.id("panel"), "open"),
-                Input("url", "search"),
-            ],
+            Input(self.id(), "data"),
+            Input(self.id("comments"), "value"),
+            Input(self.id("panel"), "open"),
+            Input("url", "search"),
         )
         def generate_description(structure, comments, panel_open, url):
-
             token = parse_token(url)
 
             if not token:
@@ -140,15 +130,12 @@ For more information, see the Materials Project
 
         @app.callback(
             Output(self.id("confirmation"), "children"),
-            [Input(self.id("submit"), "n_clicks")],
-            [
-                State(self.id(), "data"),
-                State(self.id("comments"), "value"),
-                State("url", "search"),
-            ],
+            Input(self.id("submit"), "n_clicks"),
+            State(self.id(), "data"),
+            State(self.id("comments"), "value"),
+            State("url", "search"),
         )
         def submit_snl(n_clicks, structure, comments, url):
-
             if not n_clicks:
                 raise PreventUpdate
 
@@ -174,12 +161,12 @@ For more information, see the Materials Project
             # check if structure already exists on MP
 
             with MPRester() as mpr:
-                mpids = mpr.find_structure(structure)
+                mp_ids = mpr.find_structure(structure)
 
-            if mpids:
+            if mp_ids:
                 message = (
                     f"Similar structures are already available on "
-                    f"the Materials Project, see: {', '.join(mpids)}"
+                    f"the Materials Project, see: {', '.join(mp_ids)}"
                 )
                 return MessageContainer(message, kind="warning")
 
