@@ -1,9 +1,11 @@
+from __future__ import annotations
+
 from fractions import Fraction
 
 import numpy as np
 from dash import callback_context, html
 from dash.dependencies import Input, Output
-from pymatgen.core.structure import Structure
+from pymatgen.core import Structure
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 from pymatgen.util.string import unicodeify_spacegroup, unicodeify_species
 
@@ -33,15 +35,14 @@ class SymmetryPanel(PanelComponent):
         return x_str
 
     @property
-    def title(self):
+    def title(self) -> str:
         return "Symmetry"
 
     @property
-    def description(self):
+    def description(self) -> str:
         return "Analyze the symmetry of your crystal structure or molecule."
 
     def contents_layout(self):
-
         state = {"symprec": 0.01, "angle_tolerance": 5}
 
         symprec = self.get_numerical_input(
@@ -74,19 +75,16 @@ class SymmetryPanel(PanelComponent):
             ]
         )
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         super().generate_callbacks(app, cache)
 
         @app.callback(
             Output(self.id("analysis"), "children"),
-            [
-                Input(self.id(), "data"),
-                Input(self.get_kwarg_id("symprec"), "value"),
-                Input(self.get_kwarg_id("angle_tolerance"), "value"),
-            ],
+            Input(self.id(), "data"),
+            Input(self.get_kwarg_id("symprec"), "value"),
+            Input(self.get_kwarg_id("angle_tolerance"), "value"),
         )
         def update_contents(data, symprec, angle_tolerance):
-
             if not data:
                 return html.Div()
 
