@@ -4,9 +4,9 @@ import traceback
 import warnings
 
 import dash
-import dash_daq as daq
+import dash_mp_components as mpc
 from dash import dcc, html
-from dash.dependencies import Input, Output, State
+from dash.dependencies import Component, Input, Output, State
 from dash.exceptions import PreventUpdate
 from pymatgen.transformations.transformation_abc import AbstractTransformation
 
@@ -23,8 +23,7 @@ from crystal_toolkit.settings import SETTINGS
 
 
 class TransformationComponent(MPComponent):
-    def __init__(self, input_structure_component_id: str, *args, **kwargs):
-
+    def __init__(self, input_structure_component_id: str, *args, **kwargs) -> None:
         if type(self).__name__ != f"{self.transformation.__name__}Component":
             # sanity check, enforcing conventions
             raise NameError(
@@ -49,11 +48,13 @@ class TransformationComponent(MPComponent):
         return False
 
     @property
-    def _sub_layouts(self):
-
-        enable = daq.BooleanSwitch(
+    def _sub_layouts(self) -> dict[str, Component]:
+        enable = mpc.Switch(
             id=self.id("enable_transformation"),
-            style={"display": "inline-block", "vertical-align": "middle"},
+            # style used to be passed to dash_daq.ToggleSwitch component, but not
+            # supported by mpc.Switch
+            # style={"display": "inline-block", "vertical-align": "middle"},
+            value=False,
         )
 
         message = html.Div(id=self.id("message"))
@@ -65,8 +66,8 @@ class TransformationComponent(MPComponent):
         preview = dcc.Loading(id=self.id("preview"))
 
         if self.is_one_to_many:
-            ranked_list = daq.NumericInput(
-                value=1, min=1, max=10, id=self.id("ranked_list")
+            ranked_list = dcc.Input(
+                type="number", value=1, min=1, max=10, id=self.id("ranked_list")
             )
         else:
             # if not 1-to-many, we don't need the control, we keep
@@ -84,11 +85,8 @@ class TransformationComponent(MPComponent):
         }
 
     def container_layout(self, state=None, structure=None) -> html.Div:
-        """
-        :return: Layout defining transformation and its options.
-        """
-
-        container = MessageContainer(
+        """Layout defining transformation and its options."""
+        return MessageContainer(
             [
                 MessageHeader(
                     html.Div(
@@ -130,8 +128,6 @@ class TransformationComponent(MPComponent):
             id=self.id("container"),
         )
 
-        return container
-
     def options_layouts(self, state=None, structure=None) -> list[html.Div]:
         """Return a layout to change the transformation options (that is, that controls the args and
         kwargs that will be passed to pymatgen).
@@ -141,7 +137,6 @@ class TransformationComponent(MPComponent):
         from a previous state.
 
         :param state: existing state in format {"args": [], "kwargs": {}}
-        :return:
         """
         return [html.Div()]
 
@@ -150,11 +145,11 @@ class TransformationComponent(MPComponent):
         raise NotImplementedError
 
     @property
-    def title(self):
+    def title(self) -> str:
         raise NotImplementedError
 
     @property
-    def description(self):
+    def description(self) -> str:
         raise NotImplementedError
 
     def get_preview_layout(self, struct_in, struct_out):
@@ -164,14 +159,12 @@ class TransformationComponent(MPComponent):
 
         :param struct_in: input Structure
         :param struct_out: transformed Structure
-        :return:
         """
         return html.Div()
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         @cache.memoize()
         def apply_transformation(transformation_data, struct):
-
             transformation = self.from_data(transformation_data)
             error = None
 
@@ -191,7 +184,6 @@ class TransformationComponent(MPComponent):
             return struct, error
 
         if SETTINGS.TRANSFORMATION_PREVIEWS:
-
             # Transformation previews need to be included in layout too (see preview sublayout)
             # Transformation previews need a full transformation pipeline replica (I/O heavy)
             # Might abandon.
@@ -199,7 +191,8 @@ class TransformationComponent(MPComponent):
 
             @app.callback(
                 Output(self.id("preview"), "children"),
-                [Input(self.id(), "data"), Input(self.id("input_structure"), "data")],
+                Input(self.id(), "data"),
+                Input(self.id("input_structure"), "data"),
             )
             def update_preview(transformation_data, input_structure):
                 if (not transformation_data) or (not input_structure):
@@ -211,26 +204,25 @@ class TransformationComponent(MPComponent):
                 if len(output_structure) > 64:
                     warning = html.Span(
                         f"The transformed crystal structure has {len(output_structure)} atoms "
-                        f"and might take a moment to display."
+                        "and might take a moment to display."
                     )
-                return self.get_preview_layout(input_structure, output_structure)
+                return self.get_preview_layout(
+                    input_structure, output_structure, warning
+                )
 
         @app.callback(
-            [
-                Output(self.id(), "data"),
-                Output(self.id("container"), "className"),
-                Output(self.id("message"), "children"),
-                Output(self.get_all_kwargs_id(), "disabled"),
-            ],
-            [Input(self.id("enable_transformation"), "on")],
-            [State(self.get_all_kwargs_id(), "value")],
+            Output(self.id(), "data"),
+            Output(self.id("container"), "className"),
+            Output(self.id("message"), "children"),
+            Output(self.get_all_kwargs_id(), "disabled"),
+            Input(self.id("enable_transformation"), "value"),
+            State(self.get_all_kwargs_id(), "value"),
         )
         @cache.memoize(
             timeout=60 * 60 * 24,
             make_name=lambda x: f"{type(self).__name__}_{x}_cached",
         )
         def update_transformation(enabled, states):
-
             # TODO: move callback inside AllTransformationsComponent for efficiency?
 
             kwargs = self.reconstruct_kwargs_from_state(dash.callback_context.states)
@@ -240,8 +232,7 @@ class TransformationComponent(MPComponent):
             if not enabled:
                 input_state = (False,) * len(states)
                 return None, "message is-dark", html.Div(), input_state
-            else:
-                input_state = (True,) * len(states)
+            input_state = (True,) * len(states)
 
             try:
                 trans = self.transformation(**kwargs)
@@ -251,7 +242,6 @@ class TransformationComponent(MPComponent):
                 error = str(exception)
 
             if error:
-
                 return (
                     trans,
                     "message is-warning",
@@ -259,9 +249,7 @@ class TransformationComponent(MPComponent):
                     input_state,
                 )
 
-            else:
-
-                return trans, "message is-success", html.Div(), input_state
+            return trans, "message is-success", html.Div(), input_state
 
 
 class AllTransformationsComponent(MPComponent):
@@ -271,14 +259,13 @@ class AllTransformationsComponent(MPComponent):
         input_structure_component: MPComponent | None = None,
         *args,
         **kwargs,
-    ):
+    ) -> None:
         """Create a component that can manage multiple transformations in a user-defined order.
 
         :param transformations: if provided, only offer a subset of available
             transformations, provide as a string of the given transformation name
         :param input_structure_component: will supply the structure to transform
         """
-
         # get available transformations
         subclasses = TransformationComponent.__subclasses__()
         subclass_names = [s.__name__ for s in subclasses]
@@ -308,7 +295,7 @@ class AllTransformationsComponent(MPComponent):
         self.transformations = {type(t).__name__: t for t in transformations}
 
     @property
-    def _sub_layouts(self):
+    def _sub_layouts(self) -> dict[str, Component]:
         layouts = super()._sub_layouts
 
         all_transformations = html.Div(
@@ -327,7 +314,7 @@ class AllTransformationsComponent(MPComponent):
             value=[],
             placeholder="Select one or more transformations...",
             id=self.id("choices"),
-            style={"max-width": "65vmin"},
+            style={"maxWidth": "65vmin"},
             persistence=True,
         )
 
@@ -335,8 +322,7 @@ class AllTransformationsComponent(MPComponent):
 
         return layouts
 
-    def layout(self):
-
+    def layout(self) -> html.Div:
         return html.Div(
             [
                 html.Div(
@@ -350,10 +336,9 @@ class AllTransformationsComponent(MPComponent):
             ]
         )
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         @cache.memoize()
         def apply_transformation(transformation_data, struct):
-
             transformation = self.from_data(transformation_data)
             error = None
 
@@ -380,14 +365,11 @@ class AllTransformationsComponent(MPComponent):
 
         @app.callback(
             Output(self.id("transformation_options"), "children"),
-            [
-                Input(self.id("input_structure"), "data"),
-                Input(self.id("choices"), "value"),
-            ],
-            [State(t.id(), "data") for t in self.transformations.values()],
+            Input(self.id("input_structure"), "data"),
+            Input(self.id("choices"), "value"),
+            *[State(t.id(), "data") for t in self.transformations.values()],
         )
         def show_transformation_options(structure, values, *args):
-
             # for debug
             # print(dash.callback_context.triggered)
 
@@ -395,7 +377,7 @@ class AllTransformationsComponent(MPComponent):
 
             structure = self.from_data(structure)
 
-            transformation_options = html.Div(
+            return html.Div(  # transformation_options
                 [
                     self.transformations[name].container_layout(
                         state=state, structure=structure
@@ -404,8 +386,6 @@ class AllTransformationsComponent(MPComponent):
                 ]
             )
 
-            return [transformation_options]
-
         @app.callback(
             Output(self.id("enabled-transformations"), "data"),
             Input(self.id("choices"), "value"),
@@ -419,17 +399,13 @@ class AllTransformationsComponent(MPComponent):
         # TODO: make an error store too
 
         @app.callback(
-            # [
             Output(self.id(), "data"),
-            # Output(self.id("error"), "children")],
-            [Input(t.id(), "data") for t in self.transformations.values()]
-            + [
-                Input(self.id("input_structure"), "data"),
-                Input(self.id("enabled-transformations"), "data"),
-            ],
+            # Output(self.id("error"), "children"),
+            *[Input(t.id(), "data") for t in self.transformations.values()],
+            Input(self.id("input_structure"), "data"),
+            Input(self.id("enabled-transformations"), "data"),
         )
         def run_transformations(*args):
-
             # do not update if we don't have a Structure to transform
             if not args[-2]:
                 raise PreventUpdate
@@ -442,16 +418,14 @@ class AllTransformationsComponent(MPComponent):
 
             errors = []
 
-            transformations = []
-            for transformation in args[:-2]:
-                if transformation:
-                    transformations.append(transformation)
+            transformations = [
+                transformation for transformation in args[:-2] if transformation
+            ]
 
             if not transformations:
                 return struct  # , html.Div()
 
             for transformation_data in transformations:
-
                 # following our naming convention, only apply transformations
                 # that are user visible
                 # TODO: this should be changed
@@ -459,29 +433,22 @@ class AllTransformationsComponent(MPComponent):
                     f"{transformation_data['@class']}Component"
                     in user_visible_transformations
                 ):
-
                     struct, error = apply_transformation(transformation_data, struct)
 
                     if error:
                         errors += error
 
             if not errors:
-                error_msg = html.Div()
+                html.Div()
             else:
                 errors = [
                     dcc.Markdown(
-                        "Crystal Toolkit encountered an error when trying to "
-                        "applying your chosen transformations. This is usually "
-                        "because either the input crystal structure is not "
-                        "suitable for the transformation, or the choice of "
-                        "transformation settings is not appropriate. Consult "
-                        "the pymatgen documentation for more information.  \n"
-                        ""
-                        "If you think this is a bug please report it.  \n"
-                        ""
-                    )
-                ] + errors
-                error_msg = html.Div(
+                        "Crystal Toolkit encountered an error when trying to applying your chosen "
+                        "transformations. This is usually because either the input crystal structure is not suitable for the transformation, or the choice of transformation settings is not appropriate. Consult the pymatgen documentation for more information.  \nIf you think this is a bug please report it.  \n"
+                    ),
+                    *errors,
+                ]
+                html.Div(
                     [
                         MessageContainer(
                             [
