@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import dash
 from dash import dcc
 from dash.dependencies import Input, Output, State
@@ -14,11 +16,11 @@ from crystal_toolkit.helpers.layouts import add_label_help
 
 class GrainBoundaryTransformationComponent(TransformationComponent):
     @property
-    def title(self):
+    def title(self) -> str:
         return "Make a grain boundary"
 
     @property
-    def description(self):
+    def description(self) -> str:
         return """Create a grain boundary within a periodic supercell. This transformation
 requires sensible inputs, and will be slow to run in certain cases.
 
@@ -30,7 +32,6 @@ to colour-code the top and bottom grains."""
         return GrainBoundaryTransformation
 
     def options_layouts(self, state=None, structure=None):
-
         state = state or {
             "rotation_axis": [0, 0, 1],
             "rotation_angle": None,
@@ -167,7 +168,6 @@ to colour-code the top and bottom grains."""
 
     @staticmethod
     def _get_sigmas_options_and_ratio(structure, rotation_axis):
-
         rotation_axis = [int(i) for i in rotation_axis]
 
         lat_type = (
@@ -222,23 +222,21 @@ to colour-code the top and bottom grains."""
         }
         for sigma in sorted(sigmas):
             sigma_label = f"Σ{sigma}"
-            for k, v in subscript_unicode_map.items():
-                sigma_label = sigma_label.replace(str(k), v)
+            for key, val in subscript_unicode_map.items():
+                sigma_label = sigma_label.replace(str(key), val)
             options.append({"label": sigma_label, "value": sigma})
 
         return sigmas, options, ratio
 
-    def generate_callbacks(self, app, cache):
-
+    def generate_callbacks(self, app, cache) -> None:
         super().generate_callbacks(app, cache)
 
         @app.callback(
             Output(self.id("sigma"), "options"),
-            [Input(self.get_kwarg_id("rotation_axis"), "value")],
-            [State(self.id("input_structure"), "data")],
+            Input(self.get_kwarg_id("rotation_axis"), "value"),
+            State(self.id("input_structure"), "data"),
         )
         def update_sigma_options(rotation_axis, structure):
-
             rotation_axis = self.reconstruct_kwarg_from_state(
                 dash.callback_context.inputs, "rotation_axis"
             )
@@ -256,14 +254,11 @@ to colour-code the top and bottom grains."""
 
         @app.callback(
             Output(self.id("rotation_angle", is_kwarg=True, hint="literal"), "options"),
-            [
-                Input(self.id("sigma"), "value"),
-                Input(self.get_kwarg_id("rotation_axis"), "value"),
-            ],
-            [State(self.id("input_structure"), "data")],
+            Input(self.id("sigma"), "value"),
+            Input(self.get_kwarg_id("rotation_axis"), "value"),
+            State(self.id("input_structure"), "data"),
         )
         def update_rotation_angle_options(sigma, rotation_axis, structure):
-
             if not sigma:
                 raise PreventUpdate
 
@@ -280,21 +275,17 @@ to colour-code the top and bottom grains."""
             )
 
             rotation_angles = sigmas[sigma]
-            options = []
-            for rotation_angle in sorted(rotation_angles):
-                options.append(
-                    {"label": f"{rotation_angle:.2f}º", "value": rotation_angle}
-                )
-
-            return options
+            return [
+                {"label": f"{rotation_angle:.2f}º", "value": rotation_angle}
+                for rotation_angle in sorted(rotation_angles)
+            ]
 
         # TODO: make client-side callback
         @app.callback(
-            [Output(self.id("sigma"), "value"), Output(self.id("sigma"), "disabled")],
-            [
-                Input(self.id("sigma"), "options"),
-                Input(self.id("enable_transformation"), "on"),
-            ],
+            Output(self.id("sigma"), "value"),
+            Output(self.id("sigma"), "disabled"),
+            Input(self.id("sigma"), "options"),
+            Input(self.id("enable_transformation"), "on"),
         )
         def update_default_value(options, enabled):
             if not options:
@@ -304,13 +295,9 @@ to colour-code the top and bottom grains."""
         # TODO: make client-side callback, or just combine all callbacks here
         @app.callback(
             Output(self.id("rotation_angle", is_kwarg=True, hint="literal"), "value"),
-            [
-                Input(
-                    self.id("rotation_angle", is_kwarg=True, hint="literal"), "options"
-                )
-            ],
+            Input(self.id("rotation_angle", is_kwarg=True, hint="literal"), "options"),
         )
-        def update_default_value(options):
+        def update_default_value(options):  # noqa: F811
             if not options:
                 raise PreventUpdate
             return options[0]["value"]
