@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from pymatgen.transformations.standard_transformations import SubstitutionTransformation
 
 from crystal_toolkit.components.transformations.core import TransformationComponent
@@ -5,11 +7,11 @@ from crystal_toolkit.components.transformations.core import TransformationCompon
 
 class SubstitutionTransformationComponent(TransformationComponent):
     @property
-    def title(self):
+    def title(self) -> str:
         return "Substitute one species for another"
 
     @property
-    def description(self):
+    def description(self) -> str:
         return """Replace one species in your structure (\"Previous Species\")
 with another species (\"New Species\"). The new species can be specified as an
 element (for example, O), as an element with an oxidation state (for example, O2-)
@@ -22,19 +24,16 @@ and copper). Please consult the pymatgen documentation for more information.
         return SubstitutionTransformation
 
     def options_layouts(self, state=None, structure=None):
-
         if structure and structure.is_ordered:
-            species_mapping = {
-                el: None for el in [str(el) for el in structure.types_of_specie]
-            }
+            species_mapping = {el: el for el in map(str, structure.types_of_specie)}
         else:
-            species_mapping = None
+            species_mapping = {}
 
-        state = state or {"species_mapping": species_mapping}
+        state = state or {"species_map": species_mapping}
 
         species_mapping = self.get_dict_input(
             label="Species Mapping",
-            kwarg_label="species_mapping",
+            kwarg_label="species_map",
             state=state,
             help_str="A mapping from an original species (element or element with oxidation state, e.g. O or O2-) "
             "to a new species (element, element with oxidation state, or a composition, e.g. O or O2- or "
@@ -46,12 +45,12 @@ and copper). Please consult the pymatgen documentation for more information.
 
         return [species_mapping]
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         super().generate_callbacks(app, cache)
         #
         # @app.callback(
         #     Output(self.id("transformation_args_kwargs"), "data"),
-        #     [Input(self.id("species_mapping"), "data")],
+        #     Input(self.id("species_mapping"), "data"),
         # )
         # def update_transformation_kwargs(rows):
         #     def get_el_occu(string):
