@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from dash import html
 from dash_mp_components import CrystalToolkitScene
 from pymatgen.transformations.standard_transformations import SupercellTransformation
@@ -8,11 +10,11 @@ from crystal_toolkit.core.scene import Scene
 
 class SupercellTransformationComponent(TransformationComponent):
     @property
-    def title(self):
+    def title(self) -> str:
         return "Make a supercell"
 
     @property
-    def description(self):
+    def description(self) -> str:
         return """Create a supercell by providing a scaling matrix that transforms
 input lattice vectors a, b and c into transformed lattice vectors a', b' and c'.
 
@@ -28,10 +30,9 @@ integers."""
         return SupercellTransformation
 
     def options_layouts(self, state=None, structure=None):
-
         state = state or {"scaling_matrix": ((1, 0, 0), (0, 1, 0), (0, 0, 1))}
 
-        options = self.get_numerical_input(
+        return self.get_numerical_input(
             label="Scaling matrix",
             kwarg_label="scaling_matrix",
             state=state,
@@ -40,10 +41,7 @@ integers."""
             shape=(3, 3),
         )
 
-        return [options]
-
     def get_preview_layout(self, struct_in, struct_out):
-
         if struct_in.lattice == struct_out.lattice:
             return html.Div()
 
