@@ -4,20 +4,21 @@ import os
 import warnings
 from collections import defaultdict
 from itertools import chain
-from typing import Any, cast
+from typing import TYPE_CHECKING, Any
 
-import numpy as np
 from matplotlib.cm import get_cmap
 from monty.json import MSONable
 from monty.serialization import loadfn
 from palettable.colorbrewer.qualitative import Set1_9
 from pymatgen.analysis.molecule_structure_comparator import CovalentRadius
-from pymatgen.core.periodic_table import Element, Species
-from pymatgen.core.structure import Molecule, Site, SiteCollection
+from pymatgen.core import Element, Molecule, Site, Species
 from pymatgen.util.string import unicodeify_species
 from sklearn.preprocessing import LabelEncoder
 from webcolors import html5_parse_legacy_color, html5_serialize_simple_color
 
+if TYPE_CHECKING:
+    from pymatgen.core.structure import SiteCollection
+
 # element colors forked from pymatgen
 module_dir = os.path.dirname(os.path.abspath(__file__))
 EL_COLORS = loadfn(os.path.join(module_dir, "ElementColorSchemes.yaml"))
@@ -34,7 +35,7 @@ class Legend(MSONable):
     """
 
     default_color_scheme = "Jmol"
-    default_color = [0, 0, 0]
+    default_color = (0, 0, 0)
     default_radius = 1.0
     fallback_radius = 0.5
     uniform_radius = 0.5
@@ -46,7 +47,7 @@ class Legend(MSONable):
         radius_scheme: str = "uniform",
         cmap: str = "coolwarm",
         cmap_range: tuple[float, float] | None = None,
-    ):
+    ) -> None:
         """Create a legend for a given SiteCollection to choose how to display colors and radii for
         the given sites and the species on those sites.
 
@@ -72,17 +73,18 @@ class Legend(MSONable):
             property, defines the minimum and maximum values of the
             color scape
         """
-
         if isinstance(site_collection, Site):
             site_collection = Molecule.from_sites([site_collection])
 
         site_prop_types = self.analyze_site_props(site_collection)
 
-        self.allowed_color_schemes = (
-            ["VESTA", "Jmol", "accessible"]
-            + site_prop_types.get("scalar", [])
-            + site_prop_types.get("categorical", [])
-        )
+        self.allowed_color_schemes = [
+            "VESTA",
+            "Jmol",
+            "accessible",
+            *site_prop_types.get("scalar", []),
+            *site_prop_types.get("categorical", []),
+        ]
 
         self.allowed_radius_schemes = (
             "atomic",
@@ -104,13 +106,11 @@ class Legend(MSONable):
         # maximum values for color scheme, will default to be symmetric
         # about zero
         if color_scheme in site_prop_types.get("scalar", []) and not cmap_range:
-            props = np.array(
-                [
-                    p
-                    for p in site_collection.site_properties[color_scheme]
-                    if p is not None
-                ]
-            )
+            props = [
+                p
+                for p in site_collection.site_properties[color_scheme]
+                if p is not None
+            ]
             prop_max = max([abs(min(props)), max(props)])
             prop_min = -prop_max
             cmap_range = (prop_min, prop_max)
@@ -130,7 +130,7 @@ class Legend(MSONable):
         self.color_scheme = color_scheme
         self.radius_scheme = radius_scheme
         self.cmap = cmap
-        self.cmap_range = cast(tuple[float, float], cmap_range)
+        self.cmap_range = cmap_range
 
     @staticmethod
     def generate_accessible_color_scheme_on_the_fly(
@@ -143,7 +143,6 @@ class Legend(MSONable):
 
         Returns: A dictionary in similar format to EL_COLORS
         """
-
         color_scheme = {}
 
         all_species = set(
@@ -208,28 +207,27 @@ class Legend(MSONable):
 
     @staticmethod
     def generate_categorical_color_scheme_on_the_fly(
-        site_collection: SiteCollection, site_prop_types
+        site_collection: SiteCollection, site_prop_types: dict[str, list[str]]
     ) -> dict[str, dict[str, tuple[int, int, int]]]:
-        """e.g. for Wyckoff.
+        """E.g. for Wyckoff.
 
         Args:
-            site_collection: SiteCollection
+            site_collection (SiteCollection): The sites to generate a color scheme for.
+            site_prop_types (dict[str, list[str]]): The categorical site property types.
 
         Returns: A dictionary in similar format to EL_COLORS
         """
-
         color_scheme = {}
 
         palette = Set1_9.colors
 
         for site_prop_name in site_prop_types.get("categorical", []):
-
-            props = np.array(site_collection.site_properties[site_prop_name])
+            props = site_collection.site_properties[site_prop_name]
             props[props is None] = "None"
 
-            le = LabelEncoder()
-            le.fit(props)
-            transformed_props = le.transform(props)
+            label_enc = LabelEncoder()
+            label_enc.fit(props)
+            transformed_props = label_enc.transform(props)
 
             # if we have more categories than available colors,
             # arbitrarily group some categories together
@@ -257,7 +255,6 @@ class Legend(MSONable):
 
         Returns: Color
         """
-
         # allow manual override by user
         if site and "display_color" in site.properties:
             color = site.properties["display_color"]
@@ -266,8 +263,7 @@ class Legend(MSONable):
                 color = color[0]
             if isinstance(color, list):
                 return html5_serialize_simple_color(color)
-            else:
-                return html5_serialize_simple_color(html5_parse_legacy_color(color))
+            return html5_serialize_simple_color(html5_parse_legacy_color(color))
 
         if self.color_scheme in ("VESTA", "Jmol", "accessible"):
             el = sp.as_dict()["element"]
@@ -276,7 +272,6 @@ class Legend(MSONable):
             )
 
         elif self.color_scheme in self.site_prop_types.get("scalar", []):
-
             if not site:
                 raise ValueError(
                     "Requires a site for context to get the "
@@ -286,7 +281,6 @@ class Legend(MSONable):
             prop = site.properties[self.color_scheme]
 
             if prop:
-
                 cmap = get_cmap(self.cmap)
 
                 # normalize in [0, 1] range, as expected by cmap
@@ -296,12 +290,10 @@ class Legend(MSONable):
                 color = [int(c * 255) for c in cmap(prop_normed)[0:3]]
 
             else:
-
                 # fallback if site prop is None
                 color = self.default_color
 
         elif self.color_scheme in self.site_prop_types.get("categorical", []):
-
             if not site:
                 raise ValueError(
                     "Requires a site for context to get the "
@@ -315,7 +307,6 @@ class Legend(MSONable):
             )
 
         else:
-
             raise ValueError(
                 f"Unknown color for {sp} and color scheme {self.color_scheme}."
             )
@@ -323,7 +314,6 @@ class Legend(MSONable):
         return html5_serialize_simple_color(color)
 
     def get_radius(self, sp: Species | Element, site: Site | None = None) -> float:
-
         # allow manual override by user
         if site and "display_radius" in site.properties:
             return site.properties["display_radius"]
@@ -366,14 +356,13 @@ class Legend(MSONable):
 
     @staticmethod
     def analyze_site_props(site_collection: SiteCollection) -> dict[str, list[str]]:
-        """
-        Returns: A dictionary with keys "scalar", "matrix", "vector", "categorical"
-        and values of a list of site property names corresponding to each type
+        """A dictionary with keys "scalar", "matrix", "vector", "categorical"
+        and values of a list of site property names corresponding to each type.
         """
         # (implicitly assumes all site props for a given key are same type)
         site_prop_names = defaultdict(list)
         for name, props in site_collection.site_properties.items():
-            if isinstance(props[0], float) or isinstance(props[0], int):
+            if isinstance(props[0], (int, float)):
                 site_prop_names["scalar"].append(name)
             elif isinstance(props[0], list) and len(props[0]) == 3:
                 if isinstance(props[0][0], list) and len(props[0][0]) == 3:
@@ -386,9 +375,8 @@ class Legend(MSONable):
 
     @staticmethod
     def get_species_str(sp: Species | Element) -> str:
-        """
-        Args:
-            sp: Species or Element
+        """Args:
+            sp: Species or Element.
 
         Returns: string representation
         """
@@ -397,7 +385,6 @@ class Legend(MSONable):
         return unicodeify_species(str(sp))
 
     def get_legend(self) -> dict[str, Any]:
-
         # decide what we want the labels to be
         if self.color_scheme in ("Jmol", "VESTA", "accessible"):
             label = lambda site, sp: self.get_species_str(sp)
@@ -415,13 +402,13 @@ class Legend(MSONable):
             for sp in site.species:
                 legend[self.get_color(sp, site)].append(label(site, sp))
 
-        legend = {k: ", ".join(sorted(list(set(v)))) for k, v in legend.items()}
+        legend = {key: ", ".join(sorted(set(val))) for key, val in legend.items()}
 
         color_options = []
         for site_prop_type in ("scalar", "categorical"):
             if site_prop_type in self.site_prop_types:
                 for prop in self.site_prop_types[site_prop_type]:
-                    color_options.append(prop)
+                    color_options.append(prop)  # noqa: PERF402
 
         return {
             "composition": self.site_collection.composition.as_dict(),
