@@ -1,28 +1,31 @@
 from __future__ import annotations
 
 import logging
+import re
 from abc import ABC
 from ast import literal_eval
 from base64 import b64encode
 from collections import defaultdict
-from itertools import chain
+from itertools import chain, zip_longest
 from json import JSONDecodeError, dumps, loads
-from typing import Any, Literal
+from typing import TYPE_CHECKING, Any, ClassVar, Literal
 
 import dash
 import dash_mp_components as mpc
 import numpy as np
-import plotly.graph_objects as go
-from dash import dash_table as dt
 from dash import dcc, html
 from dash.dependencies import ALL
 from flask_caching import Cache
 from monty.json import MontyDecoder, MSONable
 
 from crystal_toolkit import __version__ as ct_version
-from crystal_toolkit.helpers.layouts import Button, Icon, Loading, add_label_help
+from crystal_toolkit.helpers.layouts import H6, Button, Icon, Loading, add_label_help
 from crystal_toolkit.settings import SETTINGS
 
+if TYPE_CHECKING:
+    import plotly.graph_objects as go
+
+
 # fallback cache if Redis etc. isn't set up
 null_cache = Cache(config={"CACHE_TYPE": "null"})
 
@@ -45,15 +48,15 @@ class MPComponent(ABC):
 
     # used to track all dcc.Stores required for all MPComponents to work
     # keyed by the MPComponent id
-    _app_stores_dict: dict[str, list[dcc.Store]] = defaultdict(list)
+    _app_stores_dict: ClassVar[dict[str, list[dcc.Store]]] = defaultdict(list)
 
     # used to track what individual Dash components are defined
     # by this MPComponent
-    _all_id_basenames: set[str] = set()
+    _all_id_basenames: ClassVar[set[str]] = set()
 
     # used to defer generation of callbacks until app.layout defined
     # can be helpful to callback exceptions retained
-    _callbacks_to_generate: set[MPComponent] = set()
+    _callbacks_to_generate: ClassVar[set[MPComponent]] = set()
 
     @staticmethod
     def register_app(app: dash.Dash):
@@ -87,7 +90,8 @@ class MPComponent(ABC):
             cache: a flask_caching Cache instance
         """
         if SETTINGS.DEBUG_MODE:
-            cache = null_cache
+            MPComponent.cache = null_cache
+            MPComponent.cache.init_app(MPComponent.app.server)
         elif cache:
             MPComponent.cache = cache
         else:
@@ -97,7 +101,6 @@ class MPComponent(ABC):
 
     @staticmethod
     def crystal_toolkit_layout(layout: html.Div) -> html.Div:
-
         if not MPComponent.app:
             raise ValueError(
                 "Please register the Dash app with Crystal Toolkit using register_app()."
@@ -121,7 +124,6 @@ class MPComponent(ABC):
 
     @staticmethod
     def register_crystal_toolkit(app, layout, cache=None):
-
         MPComponent.register_app(app)
         MPComponent.register_cache(cache)
         app.config["suppress_callback_exceptions"] = True
@@ -145,7 +147,7 @@ class MPComponent(ABC):
         links: dict[str, str] | None = None,
         storage_type: Literal["memory", "local", "session"] = "memory",
         disable_callbacks: bool = False,
-    ):
+    ) -> None:
         """The abstract base class for an MPComponent.
 
         The MPComponent is designed to help render any MSONable object,
@@ -193,7 +195,6 @@ class MPComponent(ABC):
             for static layouts or returning new MPComponents dynamically where
             generating callbacks are not possible due to limitations of Dash
         """
-
         # ensure ids are unique
         # Note: shadowing Python built-in here, but only because Dash does it...
         # TODO: do something else here
@@ -203,6 +204,14 @@ class MPComponent(ABC):
             id = f"{CT_NAMESPACE}{type(self).__name__}"
         elif not id.startswith(CT_NAMESPACE):
             id = f"{CT_NAMESPACE}{id}"
+        while id in MPComponent._all_id_basenames:
+            # check if id ends with counter
+            if not re.search(r"-\d+$", id):
+                id += "-1"
+            else:
+                # increment counter at end of id until unique
+                next_ids = int(re.search(r"-(\d+)$", id).group(1)) + 1
+                id = re.sub(r"-\d+$", f"-{next_ids}", id)
         MPComponent._all_id_basenames.add(id)
 
         self._id = id
@@ -227,9 +236,8 @@ class MPComponent(ABC):
         self,
         name: str = "default",
         is_kwarg: bool = False,
-        idx=False,
-        hint=None,
-        is_store: bool = False,
+        idx: bool | int = False,
+        hint: str | None = None,
     ) -> str | dict[str, str]:
         """Generate an id from a name combined with the base id of the MPComponent itself, useful
         for generating ids of individual components in the layout.
@@ -244,23 +252,19 @@ class MPComponent(ABC):
         to parse a boolean value. In future iterations, we may be able to replace this with native
         Python type hints. The problem here is being able to specify array shape where appropriate.
 
-
         Args:
-            name: e.g. "default"
+            name (str): The name of the element, e.g. "graph", "structure". Defaults to "default".
+            is_kwarg (bool): If True, return a dict with information necessary to reconstruct
+                the keyword argument for a specific class.
+            idx (bool | int): The index to return if is_kwarg is True. Defaults to False.
+            hint (str): The type hint to return if is_kwarg is True. Defaults to None.
 
         Returns: e.g. "MPComponent_default"
         """
-
-        if name in self._stores:
-            is_store = True
-
         if is_kwarg:
-            return {
-                "component_id": self._id,
-                "kwarg_label": name,
-                "idx": str(idx),
-                "hint": str(hint),
-            }
+            return dict(
+                component_id=self._id, kwarg_label=name, idx=str(idx), hint=str(hint)
+            )
 
         # if we're linking to another component, return that id
         if name in self.links:
@@ -268,15 +272,7 @@ class MPComponent(ABC):
 
         # otherwise create a new id
         self._all_ids.add(name)
-        if name != "default":
-            name = f"{self._id}_{name}"
-        else:
-            name = f"{self._id}"
-        return name
-        if is_store:
-            return name
-        else:
-            return {"id": name}
+        return f"{self._id}_{name}" if name != "default" else f"{self._id}"
 
     def create_store(
         self,
@@ -298,13 +294,12 @@ class MPComponent(ABC):
             debug_clear: set to True to empty the store if using
             persistent storage
         """
-
         # if we're linking to another component, do not create a new store
         if name in self.links:
             return
 
         store = dcc.Store(
-            id=self.id(name, is_store=True),
+            id=self.id(name),
             data=initial_data,
             storage_type=storage_type,
             clear_data=debug_clear,
@@ -315,10 +310,7 @@ class MPComponent(ABC):
 
     @property
     def initial_data(self) -> dict[str, Any]:
-        """
-        :return: Initial data for all the stores defined by component,
-        keyed by store name.
-        """
+        """Initial data for all the stores defined by component, keyed by store name."""
         return self._initial_data
 
     @staticmethod
@@ -332,21 +324,17 @@ class MPComponent(ABC):
 
     @property
     def all_stores(self) -> list[str]:
-        """
-        :return: List of all store ids generated by this component
-        """
+        """List of all store ids generated by this component."""
         return list(self._stores)
 
     @property
     def all_ids(self) -> list[str]:
-        """
-        :return: List of all ids generated by this component
-        """
-        return list(
+        """List of all ids generated by this component."""
+        return [
             component_id
             for component_id in self._all_ids
             if component_id not in self.all_stores
-        )
+        ]
 
     def __repr__(self) -> str:
         return f"{self.id()}<{type(self).__name__}>"
@@ -355,8 +343,8 @@ class MPComponent(ABC):
         ids = "\n".join(
             [f"* {component_id}  " for component_id in sorted(self.all_ids)]
         )
-        stores = "\n".join([f"* {store}  " for store in sorted(self.all_stores)])
-        layouts = "\n".join([f"* {layout}  " for layout in sorted(self._sub_layouts)])
+        stores = "\n".join(f"* {store}  " for store in sorted(self.all_stores))
+        layouts = "\n".join(f"* {layout}  " for layout in sorted(self._sub_layouts))
 
         return f"""{self.id()}<{type(self).__name__}>  \n
 IDs:  \n{ids}  \n
@@ -374,8 +362,7 @@ Sub-layouts:  \n{layouts}"""
         return {}
 
     def layout(self) -> html.Div:
-        """
-        :return: A Dash layout for the full component. Basic implementation
+        """A Dash layout for the full component. Basic implementation
         provided, but should in general be overridden.
         """
         return html.Div(list(self._sub_layouts.values()))
@@ -387,7 +374,7 @@ Sub-layouts:  \n{layouts}"""
         all layouts will be displayed to the end user at all times, but it's important the callbacks
         are defined on the server.
         """
-        return None
+        return
 
     def get_numerical_input(
         self,
@@ -395,7 +382,7 @@ Sub-layouts:  \n{layouts}"""
         default: int | float | list | None = None,
         state: dict | None = None,
         label: str | None = None,
-        help_str: str = None,
+        help_str: str | None = None,
         is_int: bool = False,
         shape: tuple[int, ...] = (),
         **kwargs,
@@ -415,9 +402,8 @@ Sub-layouts:  \n{layouts}"""
         :param shape: (3, 3) for matrix, (1, 3) for vector, (1, 1) for scalar
         :return: a Dash layout
         """
-
         state = state or {}
-        default = np.full(shape, default or state.get(kwarg_label))
+        default = np.full(shape, state.get(kwarg_label) if default is None else default)
         default = np.reshape(default, shape)
 
         style = {
@@ -428,9 +414,7 @@ Sub-layouts:  \n{layouts}"""
             "marginBottom": "0.2rem",
             "height": "36px",
         }
-        if "style" in kwargs:
-            style.update(kwargs["style"])
-            del kwargs["style"]
+        style.update(kwargs.pop("style", {}))
 
         def matrix_element(idx, value=0):
             # TODO: maybe move element out of the name
@@ -449,22 +433,20 @@ Sub-layouts:  \n{layouts}"""
                     type="number",
                     **kwargs,
                 )
-            else:
-                return dcc.Input(
-                    id=mid,
-                    inputMode="numeric",
-                    debounce=True,
-                    className="input",
-                    style=style,
-                    value=int(value) if value is not None else None,
-                    persistence=True,
-                    type="number",
-                    step=1,
-                    **kwargs,
-                )
+            return dcc.Input(
+                id=mid,
+                inputMode="numeric",
+                debounce=True,
+                className="input",
+                style=style,
+                value=int(value) if value is not None else None,
+                persistence=True,
+                type="number",
+                **kwargs,
+            )
 
         # dict of row indices, column indices to element
-        matrix_contents = defaultdict(dict)
+        matrix_contents: dict[int, dict[int, Any]] = defaultdict(dict)
 
         # determine what individual input boxes we need
         # note that shape = () for floats, shape = (3,) for vectors
@@ -481,9 +463,10 @@ Sub-layouts:  \n{layouts}"""
         matrix_div_contents = []
         print("matrix_contents", matrix_contents)
         for column_idx in sorted(matrix_contents):
-            row = []
-            for row_idx in sorted(matrix_contents[column_idx]):
-                row.append(matrix_contents[column_idx][row_idx])
+            row = [
+                matrix_contents[column_idx][row_idx]
+                for row_idx in sorted(matrix_contents[column_idx])
+            ]
             matrix_div_contents.append(html.Div(row))
 
         matrix = html.Div(matrix_div_contents)
@@ -494,13 +477,12 @@ Sub-layouts:  \n{layouts}"""
         self,
         kwarg_label: str,
         default: Any | None = None,
-        state: dict = None,
+        state: dict | None = None,
         label: str | None = None,
-        help_str: str = None,
+        help_str: str | None = None,
         multiple: bool = False,
         **kwargs,
     ):
-
         state = state or {}
         # TODO: bug if default == 0
         default = default or state.get(kwarg_label)
@@ -530,7 +512,7 @@ Sub-layouts:  \n{layouts}"""
         default: bool | None = None,
         state: dict | None = None,
         label: str | None = None,
-        help_str: str = None,
+        help_str: str | None = None,
         **kwargs,
     ):
         """For Python classes which take boolean values as inputs, this will generate a
@@ -547,13 +529,12 @@ Sub-layouts:  \n{layouts}"""
         :param help_str: Text for a tooltip when hovering over label.
         :return: a Dash layout
         """
-
         state = state or {}
         default = default or state.get(kwarg_label) or False
 
         bool_input = mpc.Switch(
             id=self.id(kwarg_label, is_kwarg=True, hint="bool"),
-            value=True if default else False,
+            value=bool(default),
             hasLabel=True,
             **kwargs,
         )
@@ -566,7 +547,7 @@ Sub-layouts:  \n{layouts}"""
         default: str | None = None,
         state: dict | None = None,
         label: str | None = None,
-        help_str: str = None,
+        help_str: str | None = None,
         options: list[dict] | None = None,
         clearable: bool = False,
         **kwargs,
@@ -586,7 +567,6 @@ Sub-layouts:  \n{layouts}"""
         :param clearable: If True, will allow Dropdown to be cleared after a selection is made.
         :return: a Dash layout
         """
-
         state = state or {}
         default = default or state.get(kwarg_label)
 
@@ -603,47 +583,82 @@ Sub-layouts:  \n{layouts}"""
     def get_dict_input(
         self,
         kwarg_label: str,
-        default: Any | None = None,
+        default: dict | None = None,
         state: dict | None = None,
         label: str | None = None,
-        help_str: str = None,
+        help_str: str | None = None,
+        dict_size: int | None = None,
         key_name: str = "key",
         value_name: str = "value",
-    ):
-        """
+        **kwargs,
+    ) -> mpc.FilterField:
+        """For Python classes which take dictionaries as inputs. The keys are fixed and only the
+        values can be modified. This will generate a corresponding Dash input layout.
 
-        :param kwarg_label:
-        :param default:
-        :param state:
-        :param label:
-        :param help_str:
-        :param key_name:
-        :param value_name:
-        :return:
+        :param kwarg_label: The name of the corresponding Python input, this is used
+        to name the component.
+        :param label: A description for this input.
+        :param default: A default value for this input.
+        :param state: Used to set default state for this input, use a dict with the kwarg_label as a key
+        and the default value as a value. Ignored if `default` is set. It can be useful to use
+        `state` if you want to set defaults for multiple inputs from a single dictionary.
+        :param help_str: Text for a tooltip when hovering over label.
+        :param dict_size: size of the dict. Can be specified in case there is no initial default or state.
+        :param key_name: name describing the keys of the dictionary.
+        :param value_name: name describing the values of the dictionary.
+        :return: a Dash layout
         """
-
         state = state or {}
-        default = default or state.get(kwarg_label) or {}
+        default = default or state.get(kwarg_label, {})
 
-        dict_input = dt.DataTable(
-            id=self.id(kwarg_label, is_kwarg=True, hint="dict"),
-            columns=[
-                {"id": "key", "name": key_name},
-                {"id": "value", "name": value_name},
-            ],
-            data=[{"key": k, "value": v} for k, v in default.items()],
-            editable=True,
-            persistence=False,
-        )
+        dict_size = len(default) or dict_size or 0
+
+        style = {
+            "textAlign": "center",
+            "width": "20rem",
+            "marginRight": "0.2rem",
+            "marginBottom": "0.2rem",
+            "height": "36px",
+        }
+        if "style" in kwargs:
+            style.update(kwargs.pop("style"))
+
+        def pair_element(idx, key=None, value=None):
+            # TODO: maybe move element out of the name
+            kid = self.id(kwarg_label, is_kwarg=True, idx=("k", idx), hint="dict")
+            key_in = dcc.Input(
+                id=kid,
+                debounce=True,
+                className="input",
+                style=style,
+                value=value,
+                persistence=True,
+                **kwargs,
+            )
+            vid = self.id(kwarg_label, is_kwarg=True, idx=("v", idx), hint="dict")
+            value_in = dcc.Input(
+                id=vid,
+                debounce=True,
+                className="input",
+                style=style,
+                value=value,
+                persistence=True,
+                **kwargs,
+            )
+
+            return [key_in, value_in]
+
+        # arrange the input boxes in two columns
+        dict_div_contents = [html.Div(H6(f"{key_name}: {value_name}"))]
+        # dict_div_contents = []
+        for n_idx, k in zip_longest(range(dict_size), default):
+            dict_div_contents.append(html.Div(pair_element(n_idx, k, default.get(k))))
+
+        dict_input = html.Div(dict_div_contents)
 
         return add_label_help(dict_input, label, help_str)
 
     def get_kwarg_id(self, kwarg_name) -> dict[str, str]:
-        """
-
-        :param kwarg_name:
-        :return:
-        """
         return {
             "component_id": self._id,
             "kwarg_label": kwarg_name,
@@ -652,10 +667,6 @@ Sub-layouts:  \n{layouts}"""
         }
 
     def get_all_kwargs_id(self) -> dict[str, str]:
-        """
-
-        :return:
-        """
         return {"component_id": self._id, "kwarg_label": ALL, "idx": ALL, "hint": ALL}
 
     def reconstruct_kwarg_from_state(self, state, kwarg_name):
@@ -670,21 +681,19 @@ Sub-layouts:  \n{layouts}"""
         :param kwarg_labels: optional, parse only a specific kwarg or list of kwargs
         :return: A dictionary of keyword arguments with their values
         """
-
         if not state:
             state = {}
             state.update(dash.callback_context.inputs)
             state.update(dash.callback_context.states)
 
         kwargs = {}
-        for k, v in state.items():
-
+        for key, val in state.items():
             # TODO: hopefully this will be less hacky in future Dash versions
             # remove trailing ".value" and convert back into dictionary
             # need to sort k somehow ...
 
             try:
-                d = loads(k[: -len(".value")])
+                d = loads(key[: -len(".value")])
             except JSONDecodeError:
                 continue
 
@@ -701,52 +710,67 @@ Sub-layouts:  \n{layouts}"""
             idx = literal_eval(d["idx"])
 
             try:
-
                 if isinstance(k_type, tuple):
                     # matrix or vector
                     if kwarg_label not in kwargs:
                         kwargs[kwarg_label] = np.empty(k_type)
-                    v = literal_eval(str(v))
-                    if (v is not None) and (kwargs[kwarg_label] is not None):
+                    val = literal_eval(str(val))  # noqa: PLW2901
+                    if (val is not None) and (kwargs[kwarg_label] is not None):
                         # print("debugging", kwargs, kwarg_label, idx, v)
-                        if isinstance(v, list):
+                        if isinstance(val, list):
                             print(
                                 "This shouldn't happen! Debug required.",
                                 kwarg_label,
                                 idx,
-                                v,
+                                val,
                             )
                             kwargs[kwarg_label][idx] = None
                         else:
-                            kwargs[kwarg_label][idx] = v
+                            kwargs[kwarg_label][idx] = val
                     else:
                         # require all elements to have value, otherwise set
                         # entire kwarg to None
                         kwargs[kwarg_label] = None
 
                 elif k_type == "literal":
-
                     try:
-                        kwargs[kwarg_label] = literal_eval(str(v))
+                        kwargs[kwarg_label] = literal_eval(str(val))
                     except (ValueError, SyntaxError):
-                        kwargs[kwarg_label] = str(v)
+                        kwargs[kwarg_label] = str(val)
 
-                elif k_type == "bool":
-                    kwargs[kwarg_label] = v
-
-                elif k_type == "slider":
-                    kwargs[kwarg_label] = v
+                elif k_type in ("bool", "slider"):
+                    kwargs[kwarg_label] = val
 
                 elif k_type == "dict":
-                    pass
+                    # Build a temporary dictionary here to accumulate all the data.
+                    # The real dictionary will be reconstructed at the end
+                    if kwarg_label not in kwargs:
+                        kwargs[kwarg_label] = {"_tmp_dict": {"k": {}, "v": {}}}
+
+                    try:
+                        val = literal_eval(str(val))  # noqa: PLW2901
+                    except ValueError:
+                        pass
+
+                    d = kwargs[kwarg_label]["_tmp_dict"]
+                    d[idx[0]][idx[1]] = val
 
             except Exception as exc:
                 # Not raised intentionally but if you notice this in logs please investigate.
-                print("This is a problem, debug required.", exc, d, v, type(v))
+                print("This is a problem, debug required.", exc, d, val, type(val))
 
-        for k, v in kwargs.items():
-            if isinstance(v, np.ndarray):
-                kwargs[k] = v.tolist()
+        for key, val in kwargs.items():
+            if isinstance(val, np.ndarray):
+                kwargs[key] = val.tolist()
+            elif isinstance(val, dict) and "_tmp_dict" in val:
+                # reconstruct the real dict in the case hint=dict
+                full_dict = {}
+                for kv_index, k_dict in val["_tmp_dict"]["k"].items():
+                    # Ignore if the key is None
+                    if k_dict is not None:
+                        full_dict[k_dict] = val["_tmp_dict"]["v"][kv_index]
+
+                kwargs[key] = full_dict
 
         if SETTINGS.DEBUG_MODE:
             print(type(self).__name__, "kwargs", kwargs)
@@ -790,9 +814,7 @@ Sub-layouts:  \n{layouts}"""
         kaleido is installed on the server, a static image placeholder will
         be generated.
 
-        :return:
         """
-
         return html.Div(
             [
                 html.Div(
