@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from dash import html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
@@ -15,15 +17,14 @@ class PanelComponent(MPComponent):
     """
 
     @property
-    def title(self):
+    def title(self) -> str:
         return "Untitled Panel"
 
     @property
-    def description(self):
+    def description(self) -> str | None:
         return None
 
     def panel_layout(self, open_by_default=False):
-
         message = html.Div(id=self.id("message"))
 
         description = html.Div(
@@ -34,7 +35,7 @@ class PanelComponent(MPComponent):
 
         initial_contents = html.Div(id=self.id("contents"))
 
-        panel = Reveal(
+        return Reveal(
             title=self.title,
             children=[message, description, html.Br(), initial_contents],
             id=self.id("panel"),
@@ -42,21 +43,18 @@ class PanelComponent(MPComponent):
             open=open_by_default,
         )
 
-        return panel
-
     def contents_layout(self) -> html.Div:
         raise NotImplementedError
 
-    def generate_callbacks(self, app, cache):
+    def generate_callbacks(self, app, cache) -> None:
         pass
 
         @app.callback(
             Output(self.id("contents"), "children"),
-            [Input(self.id("panel_summary"), "n_clicks")],
-            [State(self.id("contents"), "children")],
+            Input(self.id("panel_summary"), "n_clicks"),
+            State(self.id("contents"), "children"),
         )
         def load_panel(panel_n_clicks, current_contents):
-
             if current_contents or panel_n_clicks is None:
                 raise PreventUpdate
 
