@@ -5,7 +5,7 @@ from collections import defaultdict
 from dataclasses import asdict, dataclass, field
 from itertools import chain
 from json import dump
-from typing import Any
+from typing import Any, Sequence
 
 """
 This module gives a Python interface to generate JSON for the
@@ -47,7 +47,7 @@ class Scene:
 
     name: str  # name for the scene, does not have to be unique
     contents: list = field(default_factory=list)
-    origin: tuple[float, float, float] = field(default=(0, 0, 0))
+    origin: Sequence[float] = field(default=(0, 0, 0))
     visible: bool = True
     lattice: list[list[float]] | None = None
     _meta: dict | None = None
@@ -58,11 +58,10 @@ class Scene:
         No good way to decide what origin to set for the new scene.
 
         :param other: another Scene
-        :return:
         """
         return Scene(
             name=f"{self.name}_{other.name}",
-            contents=self.contents + other.contents,
+            contents=[*self.contents, other.contents],
             origin=self.origin,
             visible=self.visible,
             lattice=self.lattice,
@@ -88,7 +87,6 @@ class Scene:
         :param scene: A Scene object
         :return: dict in a format that can be parsed by CrystalToolkitSceneComponent
         """
-
         merged_scene = Scene(
             name=self.name,
             contents=self.merge_primitives(self.contents),
@@ -99,16 +97,16 @@ class Scene:
         def remove_defaults(scene_dict):
             """Reduce file size of JSON by removing any key which is just its default value."""
             trimmed_dict = {}
-            for k, v in scene_dict.items():
-                if isinstance(v, dict):
-                    v = remove_defaults(v)
-                elif isinstance(v, list):
-                    trimmed_dict[k] = [
+            for key, val in scene_dict.items():
+                if isinstance(val, dict):
+                    val = remove_defaults(val)  # noqa: PLW2901
+                elif isinstance(val, list):
+                    trimmed_dict[key] = [
                         remove_defaults(item) if isinstance(item, dict) else item
-                        for item in v
+                        for item in val
                     ]
-                elif v is not None:
-                    trimmed_dict[k] = v
+                elif val is not None:
+                    trimmed_dict[key] = val
             return trimmed_dict
 
         return remove_defaults(asdict(merged_scene))
@@ -123,25 +121,23 @@ class Scene:
 
         :param filename: The filename (can include path),
         an extension will be set if not supplied.
-        :return:
         """
         # TODO: find a way to keep the original MSONable object + scene generation options alongside
         if not filename.endswith(".ctk.json"):
             filename += ".ctk.json"
-        with open(filename, "w") as f:
-            dump(self.to_json(), f)
+        with open(filename, "w") as file:
+            dump(self.to_json(), file)
 
     @property
     def bounding_box(self) -> list[list[float]]:
         """Returns the bounding box coordinates."""
         if len(self.contents) > 0:
             min_list, max_list = zip(*[p.bounding_box for p in self.contents])
-            min_x, min_y, min_z = map(min, list(zip(*min_list)))
-            max_x, max_y, max_z = map(max, list(zip(*max_list)))
+            min_x, min_y, min_z = map(min, zip(*min_list))
+            max_x, max_y, max_z = map(max, zip(*max_list))
 
             return [[min_x, min_y, min_z], [max_x, max_y, max_z]]
-        else:
-            return [[0, 0, 0], [0, 0, 0]]
+        return [[0, 0, 0], [0, 0, 0]]
 
     @staticmethod
     def merge_primitives(primitives):
@@ -316,11 +312,10 @@ class Cylinders(Primitive):
 
     @property
     def key(self):
-        return f"cylinder_{self.color}_{self.radius}_{self.reference}"
+        return f"cylinder_{self.color}_{self.radius}_{self.reference}_{self.clickable}_{self.tooltip}"
 
     @classmethod
     def merge(cls, cylinder_list):
-
         new_positionPairs = list(
             chain.from_iterable([cylinder.positionPairs for cylinder in cylinder_list])
         )
@@ -330,6 +325,8 @@ class Cylinders(Primitive):
             color=cylinder_list[0].color,
             radius=cylinder_list[0].radius,
             visible=cylinder_list[0].visible,
+            clickable=cylinder_list[0].clickable,
+            tooltip=cylinder_list[0].tooltip,
         )
 
     @property
@@ -513,7 +510,15 @@ class Arrows(Primitive):
         return f"arrow_{self.color}_{self.radius}_{self.headLength}_{self.headWidth}_{self.reference}"
 
     @classmethod
-    def merge(cls, arrow_list):
+    def merge(cls, arrow_list: list[Arrows]) -> Arrows:
+        """Merge a list of arrows into a new Arrows instance.
+
+        Args:
+            arrow_list (list[Arrows]): Arrows to merge
+
+        Returns:
+            Arrows: Merged arrows
+        """
         new_positionPairs = list(
             chain.from_iterable([arrow.positionPairs for arrow in arrow_list])
         )
@@ -529,7 +534,7 @@ class Arrows(Primitive):
     @property
     def bounding_box(self) -> list[list[float]]:
         x, y, z = zip(*chain.from_iterable(self.positionPairs))
-        return [[min(x), min(y), min(z)], [min(x), min(y), min(z)]]
+        return [[min(x), min(y), min(z)], [max(x), max(y), max(z)]]
 
 
 @dataclass
