@@ -1,4 +1,6 @@
-"""Populate the default values from the JSON file"""
+"""Populate the default values from the JSON file."""
+from __future__ import annotations
+
 import json
 import os as _os
 from collections import defaultdict
