@@ -39,19 +39,19 @@ def _update_css_class(kwargs, class_name):
 
 
 class Section(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "section")
         super().__init__(*args, **kwargs)
 
 
 class Container(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "container")
         super().__init__(*args, **kwargs)
 
 
 class Block(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "block")
         super().__init__(*args, **kwargs)
 
@@ -65,7 +65,7 @@ class Columns(html.Div):
         gapless=False,
         multiline=False,
         **kwargs,
-    ):
+    ) -> None:
         _update_css_class(kwargs, "columns")
         if desktop_only:
             kwargs["className"] += " is-desktop"
@@ -79,7 +79,14 @@ class Columns(html.Div):
 
 
 class Column(html.Div):
-    def __init__(self, *args, size=None, offset=None, narrow=False, **kwargs):
+    def __init__(
+        self,
+        *args,
+        size: str | None = None,
+        offset=None,
+        narrow: bool = False,
+        **kwargs,
+    ) -> None:
         _update_css_class(kwargs, "column")
         if size:
             kwargs["className"] += f" is-{size}"
@@ -91,7 +98,9 @@ class Column(html.Div):
 
 
 class Button(html.Button):
-    def __init__(self, *args, kind=None, size="normal", **kwargs):
+    def __init__(
+        self, *args, kind: str | None = None, size: str = "normal", **kwargs
+    ) -> None:
         _update_css_class(kwargs, f"button is-{size}")
         if kind:
             kwargs["className"] += f" is-{kind}"
@@ -99,13 +108,15 @@ class Button(html.Button):
 
 
 class Error(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "notification is-danger")
         super().__init__(*args, **kwargs)
 
 
 class MessageContainer(html.Article):
-    def __init__(self, *args, kind="warning", size="normal", **kwargs):
+    def __init__(
+        self, *args, kind: str = "warning", size: str = "normal", **kwargs
+    ) -> None:
         if kind:
             _update_css_class(kwargs, f"message is-{kind} is-{size}")
         else:
@@ -114,19 +125,21 @@ class MessageContainer(html.Article):
 
 
 class MessageHeader(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "message-header")
         super().__init__(*args, **kwargs)
 
 
 class MessageBody(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "message-body")
         super().__init__(*args, **kwargs)
 
 
 class Icon(html.Span):
-    def __init__(self, kind="download", fill="s", *args, **kwargs):
+    def __init__(
+        self, kind: str = "download", fill: str = "s", *args, **kwargs
+    ) -> None:
         """Font-awesome icon.
 
         Good options for kind are "info-circle", "question-circle", "book", "code".
@@ -141,13 +154,13 @@ class Icon(html.Span):
 
 
 class Footer(html.Footer):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "footer")
         super().__init__(*args, **kwargs)
 
 
 class Spinner(html.Button):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "button is-primary is-loading")
         kwargs["style"] = {"width": "35px", "height": "35px", "borderRadius": "35px"}
         kwargs["aria-label"] = "Loading"
@@ -155,13 +168,13 @@ class Spinner(html.Button):
 
 
 class Box(html.Div):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "box")
         super().__init__(*args, **kwargs)
 
 
 class H1(html.H1):
-    def __init__(self, *args, subtitle=False, **kwargs):
+    def __init__(self, *args, subtitle: bool = False, **kwargs) -> None:
         if subtitle:
             _update_css_class(kwargs, "subtitle is-1")
         else:
@@ -170,7 +183,7 @@ class H1(html.H1):
 
 
 class H2(html.H2):
-    def __init__(self, *args, subtitle=False, **kwargs):
+    def __init__(self, *args, subtitle: bool = False, **kwargs) -> None:
         if subtitle:
             _update_css_class(kwargs, "subtitle is-2")
         else:
@@ -179,7 +192,7 @@ class H2(html.H2):
 
 
 class H3(html.H3):
-    def __init__(self, *args, subtitle=False, **kwargs):
+    def __init__(self, *args, subtitle: bool = False, **kwargs) -> None:
         if subtitle:
             _update_css_class(kwargs, "subtitle is-3")
         else:
@@ -188,7 +201,7 @@ class H3(html.H3):
 
 
 class H4(html.H4):
-    def __init__(self, *args, subtitle=False, **kwargs):
+    def __init__(self, *args, subtitle: bool = False, **kwargs) -> None:
         if subtitle:
             _update_css_class(kwargs, "subtitle is-4")
         else:
@@ -197,7 +210,7 @@ class H4(html.H4):
 
 
 class H5(html.H5):
-    def __init__(self, *args, subtitle=False, **kwargs):
+    def __init__(self, *args, subtitle: bool = False, **kwargs) -> None:
         if subtitle:
             _update_css_class(kwargs, "subtitle is-5")
         else:
@@ -206,7 +219,7 @@ class H5(html.H5):
 
 
 class H6(html.H6):
-    def __init__(self, *args, subtitle=False, **kwargs):
+    def __init__(self, *args, subtitle: bool = False, **kwargs) -> None:
         if subtitle:
             _update_css_class(kwargs, "subtitle is-6")
         else:
@@ -221,10 +234,10 @@ class Tag(html.Div):
         tag_type="primary",
         tag_addon=None,
         tag_addon_type="primary",
-        size="normal",
+        size: str = "normal",
         *args,
         **kwargs,
-    ):
+    ) -> None:
         _update_css_class(kwargs, "tags")
         tags = [html.Span(tag, className=f"tag is-{tag_type} is-{size}")]
         if tag_addon:
@@ -236,20 +249,22 @@ class Tag(html.Div):
 
 
 class TagContainer(html.Div):
-    def __init__(self, tags: list[Tag], *args, **kwargs):
+    def __init__(self, tags: list[Tag], *args, **kwargs) -> None:
         _update_css_class(kwargs, "field is-grouped is-grouped-multiline")
         tags = [html.Div(tag, className="control") for tag in tags]
         super().__init__(tags, *args, **kwargs)
 
 
-class Textarea(html.Textarea):
-    def __init__(self, *args, **kwargs):
+class Textarea(dcc.Textarea):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "textarea")
         super().__init__(*args, **kwargs)
 
 
 class Reveal(html.Details):
-    def __init__(self, children=None, id=None, summary_id=None, title=None, **kwargs):
+    def __init__(
+        self, children=None, id=None, summary_id=None, title=None, **kwargs
+    ) -> None:
         if children is None:
             children = ["Loading..."]
         if id is None and isinstance(title, str):
@@ -276,13 +291,19 @@ class Reveal(html.Details):
 
 
 class Label(html.Label):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "label")
         super().__init__(*args, **kwargs)
 
 
 class Modal(html.Div):
-    def __init__(self, children=None, id=None, active=False, **kwargs):
+    def __init__(
+        self,
+        children: list | None = None,
+        id: str | None = None,
+        active: bool = False,
+        **kwargs,
+    ) -> None:
         _update_css_class(kwargs, "modal")
         if active:
             kwargs["className"] += " is-active"
@@ -300,8 +321,13 @@ class Modal(html.Div):
 
 class Field(html.Div):
     def __init__(
-        self, *args, addons=False, grouped=False, grouped_multiline=False, **kwargs
-    ):
+        self,
+        *args,
+        addons: bool = False,
+        grouped: bool = False,
+        grouped_multiline: bool = False,
+        **kwargs,
+    ) -> None:
         _update_css_class(kwargs, "field")
         if addons:
             kwargs["className"] += " has-addons"
@@ -313,19 +339,32 @@ class Field(html.Div):
 
 
 class Control(html.Div):
-    """Control tag to wrap form elements, see https://bulma.io/documentation/form/general/"""
+    """Control tag to wrap form elements, see https://bulma.io/documentation/form/general/."""
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         _update_css_class(kwargs, "control")
         super().__init__(*args, **kwargs)
 
 
+class Input(dcc.Input):
+    """Control tag to wrap form elements, see https://bulma.io/documentation/input/general/."""
+
+    def __init__(
+        self,
+        *args,
+        color="primary",
+        **kwargs,
+    ) -> None:
+        _update_css_class(kwargs, f"input is-{color}")
+        super().__init__(*args, **kwargs)
+
+
 def get_tooltip(
     tooltip_label: Any,
     tooltip_text: str,
     underline: bool = True,
     tooltip_id: str = "",
-    wrapper_class: str = None,
+    wrapper_class: str | None = None,
     **kwargs,
 ):
     """Uses the tooltip component from dash-mp-components to add a tooltip, typically for help text.
@@ -356,7 +395,7 @@ def get_tooltip(
     )
 
 
-def get_data_list(data: dict[str, str]):
+def get_data_list(data: dict[str, str | int | float | list[str | int | float]]):
     """Show a formatted table of data items.
 
     :param data: dictionary of label, value pairs
@@ -364,16 +403,8 @@ def get_data_list(data: dict[str, str]):
     """
     contents = []
     for title, value in data.items():
-        if isinstance(title, str):
-            title = Label(title)
-        contents.append(
-            html.Tr(
-                [
-                    html.Td(title, style={"vertical-align": "middle"}),
-                    html.Td(value, style={"vertical-align": "middle"}),
-                ]
-            )
-        )
+        label = Label(title) if isinstance(title, str) else title
+        contents.append(html.Tr([html.Td(label), html.Td(value)]))
     return html.Table([html.Tbody(contents)], className="table")
 
 
@@ -383,21 +414,18 @@ def get_table(rows: list[list[Any]], header: list[str] | None = None) -> html.Ta
     :param rows: list of list of cell contents
     :return: html.Table
     """
-    contents = []
-    for row in rows:
-        contents.append(html.Tr([html.Td(item) for item in row]))
+    contents = [html.Tr([html.Td(item) for item in row]) for row in rows]
     if not header:
         return html.Table([html.Tbody(contents)], className="table")
-    else:
-        header = html.Thead([html.Tr([html.Th(item) for item in header])])
-        return html.Table([header, html.Tbody(contents)], className="table")
+    header = html.Thead([html.Tr([html.Th(item) for item in header])])
+    return html.Table([header, html.Tbody(contents)], className="table")
 
 
 DOI_CACHE = loadfn(MODULE_PATH / "apps/assets/doi_cache.json")
 
 
 def cite_me(
-    doi: str = None, manual_ref: str = None, cite_text: str = "Cite me"
+    doi: str | None = None, manual_ref: str | None = None, cite_text: str = "Cite me"
 ) -> html.Div:
     """Create a button to show users how to cite a particular resource.
 
@@ -423,28 +451,29 @@ def add_label_help(input, label, help) -> mpc.FilterField:
 
 
 class Loading(dcc.Loading):
-    def __init__(self, *args, **kwargs):
-
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(
             *args, color=PRIMARY_COLOR, type="dot", debug=SETTINGS.DEBUG_MODE, **kwargs
         )
 
 
 def get_breadcrumb(parts):
+    """Create a breadcrumb navigation bar.
+
+    Args:
+        parts (dict): Dictionary of name, link pairs.
+
+    Returns:
+        html.Nav: Breadcrumb navigation bar.
+    """
     if not parts:
-        return html.Div()
+        return html.Nav()
 
-    breadcrumbs = html.Nav(
-        html.Ul(
-            [
-                html.Li(
-                    dcc.Link(name, href=link),
-                    className=(None if idx != len(parts) - 1 else "is-active"),
-                )
-                for idx, (name, link) in enumerate(parts.items())
-            ]
-        ),
-        className="breadcrumb",
-    )
-
-    return breadcrumbs
+    links = [
+        html.Li(
+            dcc.Link(name, href=link),
+            className="is-active" if idx == len(parts) - 1 else None,
+        )
+        for idx, (name, link) in enumerate(parts.items())
+    ]
+    return html.Nav(html.Ul(links), className="breadcrumb")
