@@ -1,4 +1,9 @@
-"""Export wrapper for POV-Ray. For creating publication quality plots."""
+"""Export wrapper for POV-Ray.
+
+For creating publication quality plots.
+"""
+from __future__ import annotations
+
 from jinja2 import Environment
 
 HEAD = """
@@ -130,10 +135,9 @@ sphere {<{{val}}>, 0.02 texture {bbox} no_shadow}
 
 
 def pov_write_data(input_scene_comp, fstream):
-    """parse a primitive display object in crystaltoolkit and print it to POV-Ray input_scene_comp
-    fstream.
+    """Parse a primitive display object in crystaltoolkit and print it to POV-Ray
+    input_scene_comp fstream.
     """
-
     vect = "{:.4f},{:.4f},{:.4f}"
 
     if input_scene_comp["type"] == "spheres":
@@ -197,28 +201,26 @@ def filter_data(scene_data, fstream):
 
 
 def write_pov_file(smc, file_name):
+    """Args:
+    smc (StructureMoleculeComponent): Object containing the scene data.
+    file_name (str): name of the file to write to.
     """
-    smc : (StructureMoleculeComponent)
-    """
-    fstream = open(file_name, "w")
-    fstream.write(HEAD)
-    fstream.write(CAMERA)
-    fstream.write(LIGHTS)
-    filter_data(smc.initial_scene_data, fstream)
-    fstream.close()
+    with open(file_name, "w") as fstream:
+        fstream.write(HEAD)
+        fstream.write(CAMERA)
+        fstream.write(LIGHTS)
+        filter_data(smc.initial_scene_data, fstream)
 
-    fstream = open("render.ini", "w")
     render_settings = get_render_settings()
-    fstream.write(render_settings)
-    fstream.close()
+    with open(file_name, "w") as file:
+        file.write(render_settings)
 
 
 def get_render_settings(file_name):
     """Creates a POV-Ray render.ini file."""
-
     image_name = f"{file_name[:-4]}.png"
 
-    settings = f"""
+    return f"""
 Input_File_Name = {file_name}
 Output_File_Name = {image_name}
 Display = 1
@@ -241,4 +243,3 @@ Declare=ii=0
 Declare=jj=0
 Declare=kk=0
 """
-    return settings
