@@ -1,16 +1,12 @@
-"""pleasant hack to support MSONable objects in Dash callbacks natively"""
-from __future__ import annotations
+"""Pleasant hack to support MSONable objects in Dash callbacks natively."""
 
-from monty.json import MSONable
+from __future__ import annotations
 
 
 def to_plotly_json(self):
     return self.as_dict()
 
 
-MSONable.to_plotly_json = to_plotly_json
-
-
 def _repr_mimebundle_(self, include=None, exclude=None):
     """Render Scenes using crystaltoolkit-extension for Jupyter Lab."""
     # TODO: add Plotly, application/vnd.plotly.v1+json
@@ -36,16 +32,12 @@ install.
             "application/vnd.mp.ctk+json": self.get_scene().to_json(),
             "text/plain": help_text_ct + repr(self),
         }
-    elif hasattr(self, "get_plot"):
+    if hasattr(self, "get_plot"):
         return {
             "application/vnd.plotly.v1+json": self.get_plot().to_plotly_json(),
             "text/plain": help_text_plotly + repr(self),
         }
-    else:
-        return {"application/json": self.as_dict(), "text/plain": repr(self)}
-
-
-MSONable._repr_mimebundle_ = _repr_mimebundle_
+    return {"application/json": self.as_dict(), "text/plain": repr(self)}
 
 
 def show_json(self):
@@ -54,9 +46,6 @@ def show_json(self):
     return display_json(self.as_dict(), raw=True)
 
 
-MSONable.show_json = show_json
-
-
 def _ipython_display_(self):
     """Render Scenes using crystaltoolkit-extension for Jupyter Lab.
 
@@ -65,6 +54,3 @@ def _ipython_display_(self):
     from IPython.display import publish_display_data
 
     publish_display_data(self._repr_mimebundle_())
-
-
-MSONable._ipython_display_ = _ipython_display_
