@@ -3,7 +3,7 @@ from __future__ import annotations
 from typing import Any, Sequence
 
 import numpy as np
-from pymatgen.core.lattice import Lattice
+from pymatgen.core import Lattice
 
 from crystal_toolkit.core.scene import Arrows, Lines, Scene, Spheres
 
@@ -15,10 +15,11 @@ def _axes_from_lattice(
     offset: float = 0,
     **kwargs: Any,
 ) -> Scene:
-    """_summary_
+    """Get the Scene object which contains a set of axes that are aligned with the
+    lattice vectors.
 
     Args:
-        origin (list[float], optional): the reference position to place the compass. Defaults to None.
+        origin (list[float], optional): the reference position to place the compass. Defaults to (0, 0, 0).
         scale (float, optional): scale all the geometric objects that makes up the compass
     the lattice vectors are normalized before the scaling so everything should. Defaults to 1.
         offset (float, optional): shift the compass from the origin by a ratio of the diagonal
@@ -78,7 +79,9 @@ def _axes_from_lattice(
     )
 
 
-def get_lattice_scene(self, origin=None, show_axes=False, **kwargs):
+def get_lattice_scene(
+    self: Lattice, origin=None, show_axes: bool = False, **kwargs
+) -> Scene:
     o = -np.array((0, 0, 0))
     a, b, c = self.matrix[0], self.matrix[1], self.matrix[2]
     line_pairs = [
@@ -109,10 +112,9 @@ def get_lattice_scene(self, origin=None, show_axes=False, **kwargs):
     ]
     line_pairs = [line.tolist() for line in line_pairs]
 
-    name = (
-        f"a={self.a}, b={self.b}, c={self.c}, "
-        f"alpha={self.alpha}, beta={self.beta}, gamma={self.gamma}"
-    )
+    a, b, c = self.abc
+    alpha, beta, gamma = self.angles
+    name = f"{a=}, {b=}, {c=}, {alpha=}, {beta=}, {gamma=}"
 
     contents = [Lines(line_pairs, **kwargs)]
 
