@@ -2,10 +2,10 @@ from __future__ import annotations
 
 from collections import defaultdict
 from itertools import combinations
+from typing import Sequence
 
 import numpy as np
-from pymatgen.core.sites import PeriodicSite
-from pymatgen.core.structure import Structure
+from pymatgen.core import PeriodicSite, Structure
 
 from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.scene import Scene
@@ -13,69 +13,66 @@ from crystal_toolkit.core.scene import Scene
 
 def _get_sites_to_draw(self, draw_image_atoms=True):
     """Returns a list of site indices and image vectors."""
-
     sites_to_draw = [(idx, (0, 0, 0)) for idx in range(len(self))]
 
-    if draw_image_atoms:
+    if not draw_image_atoms:  # return early if we don't need to search for image atoms
+        return set(sites_to_draw)
 
-        for idx, site in enumerate(self):
+    for idx, site in enumerate(self):
+        zero_elements = [
+            idx
+            for idx, frac_coord in enumerate(site.frac_coords)
+            if np.allclose(frac_coord, 0, atol=0.05)
+        ]
 
-            zero_elements = [
-                idx
-                for idx, f in enumerate(site.frac_coords)
-                if np.allclose(f, 0, atol=0.05)
-            ]
+        coord_permutations = [
+            x
+            for tmp_ in range(1, len(zero_elements) + 1)
+            for x in combinations(zero_elements, tmp_)
+        ]
 
-            coord_permutations = [
-                x
-                for tmp_ in range(1, len(zero_elements) + 1)
-                for x in combinations(zero_elements, tmp_)
-            ]
+        sites_to_draw += [
+            (idx, (int(0 in perm), int(1 in perm), int(2 in perm)))
+            for perm in coord_permutations
+        ]
 
-            for perm in coord_permutations:
-                sites_to_draw.append(
-                    (idx, (int(0 in perm), int(1 in perm), int(2 in perm)))
-                )
+        one_elements = [
+            idx
+            for idx, f in enumerate(site.frac_coords)
+            if np.allclose(f, 1, atol=0.05)
+        ]
 
-            one_elements = [
-                idx
-                for idx, f in enumerate(site.frac_coords)
-                if np.allclose(f, 1, atol=0.05)
-            ]
+        coord_permutations = [
+            x
+            for tmp_ in range(1, len(one_elements) + 1)
+            for x in combinations(one_elements, tmp_)
+        ]
 
-            coord_permutations = [
-                x
-                for tmp_ in range(1, len(one_elements) + 1)
-                for x in combinations(one_elements, tmp_)
-            ]
-
-            for perm in coord_permutations:
-                sites_to_draw.append(
-                    (idx, (-int(0 in perm), -int(1 in perm), -int(2 in perm)))
-                )
+        sites_to_draw += [
+            (idx, (-int(0 in perm), -int(1 in perm), -int(2 in perm)))
+            for perm in coord_permutations
+        ]
 
     return set(sites_to_draw)
 
 
 def get_structure_scene(
     self,
-    origin: list[float] = None,
+    origin: Sequence[float] | None = None,
     legend: Legend | None = None,
     draw_image_atoms: bool = True,
 ) -> Scene:
-    """
-    Create CTK objects for the lattice and sties
+    """Create CTK objects for the lattice and sties
     Args:
         self:  Structure object
-        origin: fractional coordinate of the origin
+        origin: x,y,z fractional coordinates of the origin
         legend: Legend for the sites
         draw_image_atoms: If true draw image atoms that are just outside the
-        periodic boundary
+        periodic boundary.
 
     Returns:
         CTK scene object to be rendered
     """
-
     origin = origin or list(-self.lattice.get_cartesian_coords([0.5, 0.5, 0.5]))
 
     legend = legend or Legend(self)
@@ -84,8 +81,7 @@ def get_structure_scene(
 
     sites_to_draw = self._get_sites_to_draw(draw_image_atoms=draw_image_atoms)
 
-    for (idx, jimage) in sites_to_draw:
-
+    for idx, jimage in sites_to_draw:
         site = self[idx]
         if jimage != (0, 0, 0):
             site = PeriodicSite(
@@ -107,7 +103,8 @@ def get_structure_scene(
         origin=origin,
         lattice=lattice_vectors,
         contents=[
-            Scene(name=k, contents=v, origin=origin) for k, v in primitives.items()
+            Scene(name=key, contents=val, origin=origin)
+            for key, val in primitives.items()
         ],
     )
 
