@@ -2,11 +2,12 @@ from __future__ import annotations
 
 from collections import defaultdict
 from itertools import combinations
+from typing import Sequence
 
 import numpy as np
 from matplotlib.cm import get_cmap
 from pymatgen.analysis.graphs import StructureGraph
-from pymatgen.core.sites import PeriodicSite
+from pymatgen.core import PeriodicSite
 
 from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.scene import Scene
@@ -16,13 +17,10 @@ def _get_sites_to_draw(
     self, draw_image_atoms=True, bonded_sites_outside_unit_cell=False
 ):
     """Returns a list of site indices and image vectors."""
-
     sites_to_draw = [(idx, (0, 0, 0)) for idx in range(len(self.structure))]
 
     if draw_image_atoms:
-
         for idx, site in enumerate(self.structure):
-
             zero_elements = [
                 idx
                 for idx, f in enumerate(site.frac_coords)
@@ -35,10 +33,10 @@ def _get_sites_to_draw(
                 for x in combinations(zero_elements, length)
             ]
 
-            for perm in coord_permutations:
-                sites_to_draw.append(
-                    (idx, (int(0 in perm), int(1 in perm), int(2 in perm)))
-                )
+            sites_to_draw += [
+                (idx, (int(0 in perm), int(1 in perm), int(2 in perm)))
+                for perm in coord_permutations
+            ]
 
             one_elements = [
                 idx
@@ -51,20 +49,18 @@ def _get_sites_to_draw(
                 for length in range(1, len(one_elements) + 1)
                 for x in combinations(one_elements, length)
             ]
-
-            for perm in coord_permutations:
-                sites_to_draw.append(
-                    (idx, (-int(0 in perm), -int(1 in perm), -int(2 in perm)))
-                )
+            sites_to_draw += [
+                (idx, (-int(0 in perm), -int(1 in perm), -int(2 in perm)))
+                for perm in coord_permutations
+            ]
 
     if bonded_sites_outside_unit_cell:
-
         sites_to_append = []
-        for (n, jimage) in sites_to_draw:
+        for n, jimage in sites_to_draw:
             connected_sites = self.get_connected_sites(n, jimage=jimage)
             for connected_site in connected_sites:
                 if connected_site.jimage != (0, 0, 0):
-                    sites_to_append.append(
+                    sites_to_append.append(  # noqa: PERF401
                         (connected_site.index, connected_site.jimage)
                     )
         sites_to_draw += sites_to_append
@@ -78,19 +74,43 @@ def _get_sites_to_draw(
 
 def get_structure_graph_scene(
     self,
-    origin=None,
-    draw_image_atoms=True,
-    bonded_sites_outside_unit_cell=True,
-    hide_incomplete_edges=False,
+    origin: Sequence[float] | None = None,
+    draw_image_atoms: bool = True,
+    bonded_sites_outside_unit_cell: bool = True,
+    hide_incomplete_edges: bool = False,
     incomplete_edge_length_scale=0.3,
-    color_edges_by_edge_weight=False,
-    edge_weight_color_scale="coolwarm",
-    explicitly_calculate_polyhedra_hull=False,
+    color_edges_by_edge_weight: bool = False,
+    edge_weight_color_scale: str = "coolwarm",
+    explicitly_calculate_polyhedra_hull: bool = False,
     legend: Legend | None = None,
     group_by_site_property: str | None = None,
     bond_radius: float = 0.1,
+    site_get_scene_kwargs: dict | None = None,
 ) -> Scene:
+    """Returns a Scene containing a representation of the StructureGraph.
 
+    Args:
+        origin (list[float], optional): origin: x,y,z coordinates of the scene's origin. Defaults to None.
+        draw_image_atoms (bool, optional): Whether to draw atoms in periodic images. Defaults to True.
+        bonded_sites_outside_unit_cell (bool, optional): Whether to draw bonds to atoms outside the
+            unit cell. Defaults to True.
+        hide_incomplete_edges (bool, optional): Whether to hide edges that are not complete (i.e. do
+            not connect to another edge). Defaults to False.
+        incomplete_edge_length_scale (float, optional): Scale factor for incomplete edges. Defaults to 0.3.
+        color_edges_by_edge_weight (bool, optional): Whether to color edges by their weight. Defaults to False.
+        edge_weight_color_scale (str, optional): Color scale to use for edge weights. Defaults to "coolwarm".
+        explicitly_calculate_polyhedra_hull (bool, optional): Whether to explicitly calculate the
+            convex hull of the polyhedra. Defaults to False.
+        legend (Legend | None, optional): Legend to use for the Scene. Defaults to None.
+        group_by_site_property (str | None, optional): If provided, will group sites by the value
+            of this property. Defaults to None.
+        bond_radius (float, optional): Radius of bonds. Defaults to 0.1.
+        site_get_scene_kwargs (dict | None, optional): Keyword arguments to pass to `Site.get_scene`
+            Defaults to None.
+
+    Returns:
+        Scene: containing a representation of the StructureGraph.
+    """
     origin = origin or list(
         -self.structure.lattice.get_cartesian_coords([0.5, 0.5, 0.5])
     )
@@ -99,7 +119,7 @@ def get_structure_graph_scene(
 
     # we get primitives from each site individually, then
     # combine into one big Scene
-    primitives = defaultdict(list)
+    primitives: dict[str, list] = defaultdict(list)
 
     sites_to_draw = self._get_sites_to_draw(
         draw_image_atoms=draw_image_atoms,
@@ -108,16 +128,14 @@ def get_structure_graph_scene(
 
     color_edges = False
     if color_edges_by_edge_weight:
-
         weights = [e[2].get("weight") for e in self.graph.edges(data=True)]
         weights = np.array([w for w in weights if w])
 
         if any(weights):
-
             cmap = get_cmap(edge_weight_color_scale)
 
             # try to keep color scheme symmetric around 0
-            weight_max = max([abs(min(weights)), max(weights)])
+            weight_max = max(*min(weights), *weights)
             weight_min = -weight_max
 
             def get_weight_color(weight):
@@ -135,10 +153,9 @@ def get_structure_graph_scene(
         # for example, if the Structure has a "wyckoff" site property
         # this might be used to allow grouping by Wyckoff position,
         # this then changes mouseover/interaction behavior with this scene
-        grouped_atom_scene_contents = defaultdict(list)
-
-    for (idx, jimage) in sites_to_draw:
+        grouped_atom_scene_contents: dict[str, list] = defaultdict(list)
 
+    for idx, jimage in sites_to_draw:
         site = self.structure[idx]
         if jimage != (0, 0, 0):
             connected_sites = self.get_connected_sites(idx, jimage=jimage)
@@ -159,7 +176,6 @@ def get_structure_graph_scene(
         ]
 
         if color_edges:
-
             connected_sites_colors = [
                 get_weight_color(cs.weight) for cs in connected_sites
             ]
@@ -168,7 +184,6 @@ def get_structure_graph_scene(
             ]
 
         else:
-
             connected_sites_colors = None
             connected_sites_not_drawn_colors = None
 
@@ -182,24 +197,22 @@ def get_structure_graph_scene(
             explicitly_calculate_polyhedra_hull=explicitly_calculate_polyhedra_hull,
             legend=legend,
             bond_radius=bond_radius,
+            **(site_get_scene_kwargs or {}),
         )
 
         for scene in site_scene.contents:
-
             if group_by_site_property and scene.name == "atoms":
-
                 group_name = f"{site.properties[group_by_site_property]}"
                 scene.contents[0].tooltip = group_name
                 grouped_atom_scene_contents[group_name] += scene.contents
 
             else:
-
                 primitives[scene.name] += scene.contents
 
     if group_by_site_property:
         atoms_scenes: list[Scene] = []
-        for k, v in grouped_atom_scene_contents.items():
-            atoms_scenes.append(Scene(name=k, contents=v))
+        for key, val in grouped_atom_scene_contents.items():
+            atoms_scenes.append(Scene(name=key, contents=val))
         primitives["atoms"] = atoms_scenes
 
     primitives["unit_cell"].append(self.structure.lattice.get_scene())
@@ -209,7 +222,8 @@ def get_structure_graph_scene(
         name="StructureGraph",
         origin=origin,
         contents=[
-            Scene(name=k, contents=v, origin=origin) for k, v in primitives.items()
+            Scene(name=key, contents=val, origin=origin)
+            for key, val in primitives.items()
         ],
     )
 
