@@ -1,4 +1,6 @@
-from typing import Literal, Optional
+from __future__ import annotations
+
+from typing import Literal, Union
 
 from pydantic import BaseSettings
 
@@ -6,6 +8,7 @@ from crystal_toolkit import MODULE_PATH
 
 
 class Settings(BaseSettings):
+    """Crystal Toolkit settings class."""
 
     DEBUG_MODE: bool = False
     MP_EMBED_MODE: bool = False
@@ -18,13 +21,15 @@ class Settings(BaseSettings):
 
     DEV_LOGIN_DISABLED: bool = True
     LOGIN_ENDPOINT: str = "https://profile.materialsproject.org/"
-    API_KEY: Optional[str] = ""
+    API_KEY: Union[str, None] = ""
     API_EXTERNAL_ENDPOINT: str = "https://api.materialsproject.org"
 
     PERSISTENCE: bool = True
     PERSISTENCE_TYPE: Literal["memory", "session", "local"] = "local"
 
     class Config:
+        """Crystal Toolkit environment variable config class."""
+
         env_prefix = "CT_"
 
 
